Package com.google.api
Class CommonLanguageSettings.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<CommonLanguageSettings.Builder>
-
- com.google.api.CommonLanguageSettings.Builder
-
- All Implemented Interfaces:
CommonLanguageSettingsOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- CommonLanguageSettings
public static final class CommonLanguageSettings.Builder extends com.google.protobuf.GeneratedMessage.Builder<CommonLanguageSettings.Builder> implements CommonLanguageSettingsOrBuilder
Required information for every language.
Protobuf typegoogle.api.CommonLanguageSettings
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Deprecated Methods Modifier and Type Method Description CommonLanguageSettings.BuilderaddAllDestinations(java.lang.Iterable<? extends ClientLibraryDestination> values)The destination where API teams want this client library to be published.CommonLanguageSettings.BuilderaddAllDestinationsValue(java.lang.Iterable<java.lang.Integer> values)The destination where API teams want this client library to be published.CommonLanguageSettings.BuilderaddDestinations(ClientLibraryDestination value)The destination where API teams want this client library to be published.CommonLanguageSettings.BuilderaddDestinationsValue(int value)The destination where API teams want this client library to be published.CommonLanguageSettingsbuild()CommonLanguageSettingsbuildPartial()CommonLanguageSettings.Builderclear()CommonLanguageSettings.BuilderclearDestinations()The destination where API teams want this client library to be published.CommonLanguageSettings.BuilderclearReferenceDocsUri()Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated.CommonLanguageSettingsgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()ClientLibraryDestinationgetDestinations(int index)The destination where API teams want this client library to be published.intgetDestinationsCount()The destination where API teams want this client library to be published.java.util.List<ClientLibraryDestination>getDestinationsList()The destination where API teams want this client library to be published.intgetDestinationsValue(int index)The destination where API teams want this client library to be published.java.util.List<java.lang.Integer>getDestinationsValueList()The destination where API teams want this client library to be published.java.lang.StringgetReferenceDocsUri()Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated.com.google.protobuf.ByteStringgetReferenceDocsUriBytes()Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated.protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()CommonLanguageSettings.BuildermergeFrom(CommonLanguageSettings other)CommonLanguageSettings.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)CommonLanguageSettings.BuildermergeFrom(com.google.protobuf.Message other)CommonLanguageSettings.BuildersetDestinations(int index, ClientLibraryDestination value)The destination where API teams want this client library to be published.CommonLanguageSettings.BuildersetDestinationsValue(int index, int value)The destination where API teams want this client library to be published.CommonLanguageSettings.BuildersetReferenceDocsUri(java.lang.String value)Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated.CommonLanguageSettings.BuildersetReferenceDocsUriBytes(com.google.protobuf.ByteString value)Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated.-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<CommonLanguageSettings.Builder>
-
clear
public CommonLanguageSettings.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<CommonLanguageSettings.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<CommonLanguageSettings.Builder>
-
getDefaultInstanceForType
public CommonLanguageSettings getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public CommonLanguageSettings build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public CommonLanguageSettings buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public CommonLanguageSettings.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<CommonLanguageSettings.Builder>
-
mergeFrom
public CommonLanguageSettings.Builder mergeFrom(CommonLanguageSettings other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<CommonLanguageSettings.Builder>
-
mergeFrom
public CommonLanguageSettings.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<CommonLanguageSettings.Builder>- Throws:
java.io.IOException
-
getReferenceDocsUri
@Deprecated public java.lang.String getReferenceDocsUri()
Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated. See google/api/client.proto;l=122Link to automatically generated reference documentation. Example: https://cloud.google.com/nodejs/docs/reference/asset/latest
string reference_docs_uri = 1 [deprecated = true];- Specified by:
getReferenceDocsUriin interfaceCommonLanguageSettingsOrBuilder- Returns:
- The referenceDocsUri.
-
getReferenceDocsUriBytes
@Deprecated public com.google.protobuf.ByteString getReferenceDocsUriBytes()
Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated. See google/api/client.proto;l=122Link to automatically generated reference documentation. Example: https://cloud.google.com/nodejs/docs/reference/asset/latest
string reference_docs_uri = 1 [deprecated = true];- Specified by:
getReferenceDocsUriBytesin interfaceCommonLanguageSettingsOrBuilder- Returns:
- The bytes for referenceDocsUri.
-
setReferenceDocsUri
@Deprecated public CommonLanguageSettings.Builder setReferenceDocsUri(java.lang.String value)
Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated. See google/api/client.proto;l=122Link to automatically generated reference documentation. Example: https://cloud.google.com/nodejs/docs/reference/asset/latest
string reference_docs_uri = 1 [deprecated = true];- Parameters:
value- The referenceDocsUri to set.- Returns:
- This builder for chaining.
-
clearReferenceDocsUri
@Deprecated public CommonLanguageSettings.Builder clearReferenceDocsUri()
Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated. See google/api/client.proto;l=122Link to automatically generated reference documentation. Example: https://cloud.google.com/nodejs/docs/reference/asset/latest
string reference_docs_uri = 1 [deprecated = true];- Returns:
- This builder for chaining.
-
setReferenceDocsUriBytes
@Deprecated public CommonLanguageSettings.Builder setReferenceDocsUriBytes(com.google.protobuf.ByteString value)
Deprecated.google.api.CommonLanguageSettings.reference_docs_uri is deprecated. See google/api/client.proto;l=122Link to automatically generated reference documentation. Example: https://cloud.google.com/nodejs/docs/reference/asset/latest
string reference_docs_uri = 1 [deprecated = true];- Parameters:
value- The bytes for referenceDocsUri to set.- Returns:
- This builder for chaining.
-
getDestinationsList
public java.util.List<ClientLibraryDestination> getDestinationsList()
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Specified by:
getDestinationsListin interfaceCommonLanguageSettingsOrBuilder- Returns:
- A list containing the destinations.
-
getDestinationsCount
public int getDestinationsCount()
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Specified by:
getDestinationsCountin interfaceCommonLanguageSettingsOrBuilder- Returns:
- The count of destinations.
-
getDestinations
public ClientLibraryDestination getDestinations(int index)
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Specified by:
getDestinationsin interfaceCommonLanguageSettingsOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The destinations at the given index.
-
setDestinations
public CommonLanguageSettings.Builder setDestinations(int index, ClientLibraryDestination value)
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Parameters:
index- The index to set the value at.value- The destinations to set.- Returns:
- This builder for chaining.
-
addDestinations
public CommonLanguageSettings.Builder addDestinations(ClientLibraryDestination value)
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Parameters:
value- The destinations to add.- Returns:
- This builder for chaining.
-
addAllDestinations
public CommonLanguageSettings.Builder addAllDestinations(java.lang.Iterable<? extends ClientLibraryDestination> values)
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Parameters:
values- The destinations to add.- Returns:
- This builder for chaining.
-
clearDestinations
public CommonLanguageSettings.Builder clearDestinations()
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Returns:
- This builder for chaining.
-
getDestinationsValueList
public java.util.List<java.lang.Integer> getDestinationsValueList()
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Specified by:
getDestinationsValueListin interfaceCommonLanguageSettingsOrBuilder- Returns:
- A list containing the enum numeric values on the wire for destinations.
-
getDestinationsValue
public int getDestinationsValue(int index)
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Specified by:
getDestinationsValuein interfaceCommonLanguageSettingsOrBuilder- Parameters:
index- The index of the value to return.- Returns:
- The enum numeric value on the wire of destinations at the given index.
-
setDestinationsValue
public CommonLanguageSettings.Builder setDestinationsValue(int index, int value)
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Parameters:
index- The index to set the value at.value- The enum numeric value on the wire for destinations to set.- Returns:
- This builder for chaining.
-
addDestinationsValue
public CommonLanguageSettings.Builder addDestinationsValue(int value)
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Parameters:
value- The enum numeric value on the wire for destinations to add.- Returns:
- This builder for chaining.
-
addAllDestinationsValue
public CommonLanguageSettings.Builder addAllDestinationsValue(java.lang.Iterable<java.lang.Integer> values)
The destination where API teams want this client library to be published.
repeated .google.api.ClientLibraryDestination destinations = 2;- Parameters:
values- The enum numeric values on the wire for destinations to add.- Returns:
- This builder for chaining.
-
-