Package com.google.api
Class Distribution.BucketOptions.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Builder>
-
- com.google.api.Distribution.BucketOptions.Builder
-
- All Implemented Interfaces:
Distribution.BucketOptionsOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- Distribution.BucketOptions
public static final class Distribution.BucketOptions.Builder extends com.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Builder> implements Distribution.BucketOptionsOrBuilder
`BucketOptions` describes the bucket boundaries used to create a histogram for the distribution. The buckets can be in a linear sequence, an exponential sequence, or each bucket can be specified explicitly. `BucketOptions` does not include the number of values in each bucket. A bucket has an inclusive lower bound and exclusive upper bound for the values that are counted for that bucket. The upper bound of a bucket must be strictly greater than the lower bound. The sequence of N buckets for a distribution consists of an underflow bucket (number 0), zero or more finite buckets (number 1 through N - 2) and an overflow bucket (number N - 1). The buckets are contiguous: the lower bound of bucket i (i > 0) is the same as the upper bound of bucket i - 1. The buckets span the whole range of finite values: lower bound of the underflow bucket is -infinity and the upper bound of the overflow bucket is +infinity. The finite buckets are so-called because both bounds are finite.
Protobuf typegoogle.api.Distribution.BucketOptions
-
-
Method Summary
-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Builder>
-
clear
public Distribution.BucketOptions.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Builder>
-
getDefaultInstanceForType
public Distribution.BucketOptions getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public Distribution.BucketOptions build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public Distribution.BucketOptions buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public Distribution.BucketOptions.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Distribution.BucketOptions.Builder>
-
mergeFrom
public Distribution.BucketOptions.Builder mergeFrom(Distribution.BucketOptions other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Builder>
-
mergeFrom
public Distribution.BucketOptions.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Distribution.BucketOptions.Builder>- Throws:
java.io.IOException
-
getOptionsCase
public Distribution.BucketOptions.OptionsCase getOptionsCase()
- Specified by:
getOptionsCasein interfaceDistribution.BucketOptionsOrBuilder
-
clearOptions
public Distribution.BucketOptions.Builder clearOptions()
-
hasLinearBuckets
public boolean hasLinearBuckets()
The linear bucket.
.google.api.Distribution.BucketOptions.Linear linear_buckets = 1;- Specified by:
hasLinearBucketsin interfaceDistribution.BucketOptionsOrBuilder- Returns:
- Whether the linearBuckets field is set.
-
getLinearBuckets
public Distribution.BucketOptions.Linear getLinearBuckets()
The linear bucket.
.google.api.Distribution.BucketOptions.Linear linear_buckets = 1;- Specified by:
getLinearBucketsin interfaceDistribution.BucketOptionsOrBuilder- Returns:
- The linearBuckets.
-
setLinearBuckets
public Distribution.BucketOptions.Builder setLinearBuckets(Distribution.BucketOptions.Linear value)
The linear bucket.
.google.api.Distribution.BucketOptions.Linear linear_buckets = 1;
-
setLinearBuckets
public Distribution.BucketOptions.Builder setLinearBuckets(Distribution.BucketOptions.Linear.Builder builderForValue)
The linear bucket.
.google.api.Distribution.BucketOptions.Linear linear_buckets = 1;
-
mergeLinearBuckets
public Distribution.BucketOptions.Builder mergeLinearBuckets(Distribution.BucketOptions.Linear value)
The linear bucket.
.google.api.Distribution.BucketOptions.Linear linear_buckets = 1;
-
clearLinearBuckets
public Distribution.BucketOptions.Builder clearLinearBuckets()
The linear bucket.
.google.api.Distribution.BucketOptions.Linear linear_buckets = 1;
-
getLinearBucketsBuilder
public Distribution.BucketOptions.Linear.Builder getLinearBucketsBuilder()
The linear bucket.
.google.api.Distribution.BucketOptions.Linear linear_buckets = 1;
-
getLinearBucketsOrBuilder
public Distribution.BucketOptions.LinearOrBuilder getLinearBucketsOrBuilder()
The linear bucket.
.google.api.Distribution.BucketOptions.Linear linear_buckets = 1;- Specified by:
getLinearBucketsOrBuilderin interfaceDistribution.BucketOptionsOrBuilder
-
hasExponentialBuckets
public boolean hasExponentialBuckets()
The exponential buckets.
.google.api.Distribution.BucketOptions.Exponential exponential_buckets = 2;- Specified by:
hasExponentialBucketsin interfaceDistribution.BucketOptionsOrBuilder- Returns:
- Whether the exponentialBuckets field is set.
-
getExponentialBuckets
public Distribution.BucketOptions.Exponential getExponentialBuckets()
The exponential buckets.
.google.api.Distribution.BucketOptions.Exponential exponential_buckets = 2;- Specified by:
getExponentialBucketsin interfaceDistribution.BucketOptionsOrBuilder- Returns:
- The exponentialBuckets.
-
setExponentialBuckets
public Distribution.BucketOptions.Builder setExponentialBuckets(Distribution.BucketOptions.Exponential value)
The exponential buckets.
.google.api.Distribution.BucketOptions.Exponential exponential_buckets = 2;
-
setExponentialBuckets
public Distribution.BucketOptions.Builder setExponentialBuckets(Distribution.BucketOptions.Exponential.Builder builderForValue)
The exponential buckets.
.google.api.Distribution.BucketOptions.Exponential exponential_buckets = 2;
-
mergeExponentialBuckets
public Distribution.BucketOptions.Builder mergeExponentialBuckets(Distribution.BucketOptions.Exponential value)
The exponential buckets.
.google.api.Distribution.BucketOptions.Exponential exponential_buckets = 2;
-
clearExponentialBuckets
public Distribution.BucketOptions.Builder clearExponentialBuckets()
The exponential buckets.
.google.api.Distribution.BucketOptions.Exponential exponential_buckets = 2;
-
getExponentialBucketsBuilder
public Distribution.BucketOptions.Exponential.Builder getExponentialBucketsBuilder()
The exponential buckets.
.google.api.Distribution.BucketOptions.Exponential exponential_buckets = 2;
-
getExponentialBucketsOrBuilder
public Distribution.BucketOptions.ExponentialOrBuilder getExponentialBucketsOrBuilder()
The exponential buckets.
.google.api.Distribution.BucketOptions.Exponential exponential_buckets = 2;- Specified by:
getExponentialBucketsOrBuilderin interfaceDistribution.BucketOptionsOrBuilder
-
hasExplicitBuckets
public boolean hasExplicitBuckets()
The explicit buckets.
.google.api.Distribution.BucketOptions.Explicit explicit_buckets = 3;- Specified by:
hasExplicitBucketsin interfaceDistribution.BucketOptionsOrBuilder- Returns:
- Whether the explicitBuckets field is set.
-
getExplicitBuckets
public Distribution.BucketOptions.Explicit getExplicitBuckets()
The explicit buckets.
.google.api.Distribution.BucketOptions.Explicit explicit_buckets = 3;- Specified by:
getExplicitBucketsin interfaceDistribution.BucketOptionsOrBuilder- Returns:
- The explicitBuckets.
-
setExplicitBuckets
public Distribution.BucketOptions.Builder setExplicitBuckets(Distribution.BucketOptions.Explicit value)
The explicit buckets.
.google.api.Distribution.BucketOptions.Explicit explicit_buckets = 3;
-
setExplicitBuckets
public Distribution.BucketOptions.Builder setExplicitBuckets(Distribution.BucketOptions.Explicit.Builder builderForValue)
The explicit buckets.
.google.api.Distribution.BucketOptions.Explicit explicit_buckets = 3;
-
mergeExplicitBuckets
public Distribution.BucketOptions.Builder mergeExplicitBuckets(Distribution.BucketOptions.Explicit value)
The explicit buckets.
.google.api.Distribution.BucketOptions.Explicit explicit_buckets = 3;
-
clearExplicitBuckets
public Distribution.BucketOptions.Builder clearExplicitBuckets()
The explicit buckets.
.google.api.Distribution.BucketOptions.Explicit explicit_buckets = 3;
-
getExplicitBucketsBuilder
public Distribution.BucketOptions.Explicit.Builder getExplicitBucketsBuilder()
The explicit buckets.
.google.api.Distribution.BucketOptions.Explicit explicit_buckets = 3;
-
getExplicitBucketsOrBuilder
public Distribution.BucketOptions.ExplicitOrBuilder getExplicitBucketsOrBuilder()
The explicit buckets.
.google.api.Distribution.BucketOptions.Explicit explicit_buckets = 3;- Specified by:
getExplicitBucketsOrBuilderin interfaceDistribution.BucketOptionsOrBuilder
-
-