Package com.google.api
Class Distribution.BucketOptions.Exponential.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Exponential.Builder>
-
- com.google.api.Distribution.BucketOptions.Exponential.Builder
-
- All Implemented Interfaces:
Distribution.BucketOptions.ExponentialOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- Distribution.BucketOptions.Exponential
public static final class Distribution.BucketOptions.Exponential.Builder extends com.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Exponential.Builder> implements Distribution.BucketOptions.ExponentialOrBuilder
Specifies an exponential sequence of buckets that have a width that is proportional to the value of the lower bound. Each bucket represents a constant relative uncertainty on a specific value in the bucket. There are `num_finite_buckets + 2` (= N) buckets. Bucket `i` has the following boundaries: Upper bound (0 <= i < N-1): scale * (growth_factor ^ i). Lower bound (1 <= i < N): scale * (growth_factor ^ (i - 1)).
Protobuf typegoogle.api.Distribution.BucketOptions.Exponential
-
-
Method Summary
-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Exponential.Builder>
-
clear
public Distribution.BucketOptions.Exponential.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Exponential.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Exponential.Builder>
-
getDefaultInstanceForType
public Distribution.BucketOptions.Exponential getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public Distribution.BucketOptions.Exponential build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public Distribution.BucketOptions.Exponential buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public Distribution.BucketOptions.Exponential.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Distribution.BucketOptions.Exponential.Builder>
-
mergeFrom
public Distribution.BucketOptions.Exponential.Builder mergeFrom(Distribution.BucketOptions.Exponential other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Exponential.Builder>
-
mergeFrom
public Distribution.BucketOptions.Exponential.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Distribution.BucketOptions.Exponential.Builder>- Throws:
java.io.IOException
-
getNumFiniteBuckets
public int getNumFiniteBuckets()
Must be greater than 0.
int32 num_finite_buckets = 1;- Specified by:
getNumFiniteBucketsin interfaceDistribution.BucketOptions.ExponentialOrBuilder- Returns:
- The numFiniteBuckets.
-
setNumFiniteBuckets
public Distribution.BucketOptions.Exponential.Builder setNumFiniteBuckets(int value)
Must be greater than 0.
int32 num_finite_buckets = 1;- Parameters:
value- The numFiniteBuckets to set.- Returns:
- This builder for chaining.
-
clearNumFiniteBuckets
public Distribution.BucketOptions.Exponential.Builder clearNumFiniteBuckets()
Must be greater than 0.
int32 num_finite_buckets = 1;- Returns:
- This builder for chaining.
-
getGrowthFactor
public double getGrowthFactor()
Must be greater than 1.
double growth_factor = 2;- Specified by:
getGrowthFactorin interfaceDistribution.BucketOptions.ExponentialOrBuilder- Returns:
- The growthFactor.
-
setGrowthFactor
public Distribution.BucketOptions.Exponential.Builder setGrowthFactor(double value)
Must be greater than 1.
double growth_factor = 2;- Parameters:
value- The growthFactor to set.- Returns:
- This builder for chaining.
-
clearGrowthFactor
public Distribution.BucketOptions.Exponential.Builder clearGrowthFactor()
Must be greater than 1.
double growth_factor = 2;- Returns:
- This builder for chaining.
-
getScale
public double getScale()
Must be greater than 0.
double scale = 3;- Specified by:
getScalein interfaceDistribution.BucketOptions.ExponentialOrBuilder- Returns:
- The scale.
-
setScale
public Distribution.BucketOptions.Exponential.Builder setScale(double value)
Must be greater than 0.
double scale = 3;- Parameters:
value- The scale to set.- Returns:
- This builder for chaining.
-
clearScale
public Distribution.BucketOptions.Exponential.Builder clearScale()
Must be greater than 0.
double scale = 3;- Returns:
- This builder for chaining.
-
-