Class Distribution.Exemplar

  • All Implemented Interfaces:
    Distribution.ExemplarOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, java.io.Serializable
    Enclosing class:
    Distribution

    public static final class Distribution.Exemplar
    extends com.google.protobuf.GeneratedMessage
    implements Distribution.ExemplarOrBuilder
     Exemplars are example points that may be used to annotate aggregated
     distribution values. They are metadata that gives information about a
     particular value added to a Distribution bucket, such as a trace ID that
     was active when a value was added. They may contain further information,
     such as a example values and timestamps, origin, etc.
     
    Protobuf type google.api.Distribution.Exemplar
    See Also:
    Serialized Form
    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      static class  Distribution.Exemplar.Builder
      Exemplars are example points that may be used to annotate aggregated distribution values.
      • Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessage

        com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>,​BuilderT extends com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT,​BuilderT>>, com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.FieldAccessorTable, com.google.protobuf.GeneratedMessage.GeneratedExtension<ContainingT extends com.google.protobuf.Message,​T extends java.lang.Object>, com.google.protobuf.GeneratedMessage.UnusedPrivateParameter
      • Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessage

        com.google.protobuf.AbstractMessage.BuilderParent
      • Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessageLite

        com.google.protobuf.AbstractMessageLite.InternalOneOfEnum
    • Field Summary

      Fields 
      Modifier and Type Field Description
      static int ATTACHMENTS_FIELD_NUMBER  
      static int TIMESTAMP_FIELD_NUMBER  
      static int VALUE_FIELD_NUMBER  
      • Fields inherited from class com.google.protobuf.GeneratedMessage

        alwaysUseFieldBuilders, unknownFields
      • Fields inherited from class com.google.protobuf.AbstractMessage

        memoizedSize
      • Fields inherited from class com.google.protobuf.AbstractMessageLite

        memoizedHashCode
    • Method Detail

      • getDescriptor

        public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
      • internalGetFieldAccessorTable

        protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
        Specified by:
        internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessage
      • getValue

        public double getValue()
         Value of the exemplar point. This value determines to which bucket the
         exemplar belongs.
         
        double value = 1;
        Specified by:
        getValue in interface Distribution.ExemplarOrBuilder
        Returns:
        The value.
      • hasTimestamp

        public boolean hasTimestamp()
         The observation (sampling) time of the above value.
         
        .google.protobuf.Timestamp timestamp = 2;
        Specified by:
        hasTimestamp in interface Distribution.ExemplarOrBuilder
        Returns:
        Whether the timestamp field is set.
      • getAttachmentsList

        public java.util.List<Any> getAttachmentsList()
         Contextual information about the example value. Examples are:
        
         Trace: type.googleapis.com/google.monitoring.v3.SpanContext
        
         Literal string: type.googleapis.com/google.protobuf.StringValue
        
         Labels dropped during aggregation:
         type.googleapis.com/google.monitoring.v3.DroppedLabels
        
         There may be only a single attachment of any given message type in a
         single exemplar, and this is enforced by the system.
         
        repeated .google.protobuf.Any attachments = 3;
        Specified by:
        getAttachmentsList in interface Distribution.ExemplarOrBuilder
      • getAttachmentsOrBuilderList

        public java.util.List<? extends AnyOrBuilder> getAttachmentsOrBuilderList()
         Contextual information about the example value. Examples are:
        
         Trace: type.googleapis.com/google.monitoring.v3.SpanContext
        
         Literal string: type.googleapis.com/google.protobuf.StringValue
        
         Labels dropped during aggregation:
         type.googleapis.com/google.monitoring.v3.DroppedLabels
        
         There may be only a single attachment of any given message type in a
         single exemplar, and this is enforced by the system.
         
        repeated .google.protobuf.Any attachments = 3;
        Specified by:
        getAttachmentsOrBuilderList in interface Distribution.ExemplarOrBuilder
      • getAttachmentsCount

        public int getAttachmentsCount()
         Contextual information about the example value. Examples are:
        
         Trace: type.googleapis.com/google.monitoring.v3.SpanContext
        
         Literal string: type.googleapis.com/google.protobuf.StringValue
        
         Labels dropped during aggregation:
         type.googleapis.com/google.monitoring.v3.DroppedLabels
        
         There may be only a single attachment of any given message type in a
         single exemplar, and this is enforced by the system.
         
        repeated .google.protobuf.Any attachments = 3;
        Specified by:
        getAttachmentsCount in interface Distribution.ExemplarOrBuilder
      • getAttachments

        public Any getAttachments​(int index)
         Contextual information about the example value. Examples are:
        
         Trace: type.googleapis.com/google.monitoring.v3.SpanContext
        
         Literal string: type.googleapis.com/google.protobuf.StringValue
        
         Labels dropped during aggregation:
         type.googleapis.com/google.monitoring.v3.DroppedLabels
        
         There may be only a single attachment of any given message type in a
         single exemplar, and this is enforced by the system.
         
        repeated .google.protobuf.Any attachments = 3;
        Specified by:
        getAttachments in interface Distribution.ExemplarOrBuilder
      • getAttachmentsOrBuilder

        public AnyOrBuilder getAttachmentsOrBuilder​(int index)
         Contextual information about the example value. Examples are:
        
         Trace: type.googleapis.com/google.monitoring.v3.SpanContext
        
         Literal string: type.googleapis.com/google.protobuf.StringValue
        
         Labels dropped during aggregation:
         type.googleapis.com/google.monitoring.v3.DroppedLabels
        
         There may be only a single attachment of any given message type in a
         single exemplar, and this is enforced by the system.
         
        repeated .google.protobuf.Any attachments = 3;
        Specified by:
        getAttachmentsOrBuilder in interface Distribution.ExemplarOrBuilder
      • isInitialized

        public final boolean isInitialized()
        Specified by:
        isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
        Overrides:
        isInitialized in class com.google.protobuf.GeneratedMessage
      • writeTo

        public void writeTo​(com.google.protobuf.CodedOutputStream output)
                     throws java.io.IOException
        Specified by:
        writeTo in interface com.google.protobuf.MessageLite
        Overrides:
        writeTo in class com.google.protobuf.GeneratedMessage
        Throws:
        java.io.IOException
      • getSerializedSize

        public int getSerializedSize()
        Specified by:
        getSerializedSize in interface com.google.protobuf.MessageLite
        Overrides:
        getSerializedSize in class com.google.protobuf.GeneratedMessage
      • equals

        public boolean equals​(java.lang.Object obj)
        Specified by:
        equals in interface com.google.protobuf.Message
        Overrides:
        equals in class com.google.protobuf.AbstractMessage
      • hashCode

        public int hashCode()
        Specified by:
        hashCode in interface com.google.protobuf.Message
        Overrides:
        hashCode in class com.google.protobuf.AbstractMessage
      • parseFrom

        public static Distribution.Exemplar parseFrom​(java.nio.ByteBuffer data)
                                               throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(java.nio.ByteBuffer data,
                                                      com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                               throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(com.google.protobuf.ByteString data)
                                               throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(com.google.protobuf.ByteString data,
                                                      com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                               throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(byte[] data)
                                               throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(byte[] data,
                                                      com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                               throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(java.io.InputStream input)
                                               throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(java.io.InputStream input,
                                                      com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                               throws java.io.IOException
        Throws:
        java.io.IOException
      • parseDelimitedFrom

        public static Distribution.Exemplar parseDelimitedFrom​(java.io.InputStream input)
                                                        throws java.io.IOException
        Throws:
        java.io.IOException
      • parseDelimitedFrom

        public static Distribution.Exemplar parseDelimitedFrom​(java.io.InputStream input,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(com.google.protobuf.CodedInputStream input)
                                               throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static Distribution.Exemplar parseFrom​(com.google.protobuf.CodedInputStream input,
                                                      com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                               throws java.io.IOException
        Throws:
        java.io.IOException
      • newBuilderForType

        public Distribution.Exemplar.Builder newBuilderForType()
        Specified by:
        newBuilderForType in interface com.google.protobuf.Message
        Specified by:
        newBuilderForType in interface com.google.protobuf.MessageLite
      • toBuilder

        public Distribution.Exemplar.Builder toBuilder()
        Specified by:
        toBuilder in interface com.google.protobuf.Message
        Specified by:
        toBuilder in interface com.google.protobuf.MessageLite
      • newBuilderForType

        protected Distribution.Exemplar.Builder newBuilderForType​(com.google.protobuf.AbstractMessage.BuilderParent parent)
        Overrides:
        newBuilderForType in class com.google.protobuf.AbstractMessage
      • getParserForType

        public com.google.protobuf.Parser<Distribution.Exemplar> getParserForType()
        Specified by:
        getParserForType in interface com.google.protobuf.Message
        Specified by:
        getParserForType in interface com.google.protobuf.MessageLite
        Overrides:
        getParserForType in class com.google.protobuf.GeneratedMessage
      • getDefaultInstanceForType

        public Distribution.Exemplar getDefaultInstanceForType()
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder