Package com.google.api
Class LogDescriptor.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<LogDescriptor.Builder>
-
- com.google.api.LogDescriptor.Builder
-
- All Implemented Interfaces:
LogDescriptorOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- LogDescriptor
public static final class LogDescriptor.Builder extends com.google.protobuf.GeneratedMessage.Builder<LogDescriptor.Builder> implements LogDescriptorOrBuilder
A description of a log type. Example in YAML format: - name: library.googleapis.com/activity_history description: The history of borrowing and returning library items. display_name: Activity labels: - key: /customer_id description: Identifier of a library customer
Protobuf typegoogle.api.LogDescriptor
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description LogDescriptor.BuilderaddAllLabels(java.lang.Iterable<? extends LabelDescriptor> values)The set of labels that are available to describe a specific log entry.LogDescriptor.BuilderaddLabels(int index, LabelDescriptor value)The set of labels that are available to describe a specific log entry.LogDescriptor.BuilderaddLabels(int index, LabelDescriptor.Builder builderForValue)The set of labels that are available to describe a specific log entry.LogDescriptor.BuilderaddLabels(LabelDescriptor value)The set of labels that are available to describe a specific log entry.LogDescriptor.BuilderaddLabels(LabelDescriptor.Builder builderForValue)The set of labels that are available to describe a specific log entry.LabelDescriptor.BuilderaddLabelsBuilder()The set of labels that are available to describe a specific log entry.LabelDescriptor.BuilderaddLabelsBuilder(int index)The set of labels that are available to describe a specific log entry.LogDescriptorbuild()LogDescriptorbuildPartial()LogDescriptor.Builderclear()LogDescriptor.BuilderclearDescription()A human-readable description of this log.LogDescriptor.BuilderclearDisplayName()The human-readable name for this log.LogDescriptor.BuilderclearLabels()The set of labels that are available to describe a specific log entry.LogDescriptor.BuilderclearName()The name of the log.LogDescriptorgetDefaultInstanceForType()java.lang.StringgetDescription()A human-readable description of this log.com.google.protobuf.ByteStringgetDescriptionBytes()A human-readable description of this log.static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()java.lang.StringgetDisplayName()The human-readable name for this log.com.google.protobuf.ByteStringgetDisplayNameBytes()The human-readable name for this log.LabelDescriptorgetLabels(int index)The set of labels that are available to describe a specific log entry.LabelDescriptor.BuildergetLabelsBuilder(int index)The set of labels that are available to describe a specific log entry.java.util.List<LabelDescriptor.Builder>getLabelsBuilderList()The set of labels that are available to describe a specific log entry.intgetLabelsCount()The set of labels that are available to describe a specific log entry.java.util.List<LabelDescriptor>getLabelsList()The set of labels that are available to describe a specific log entry.LabelDescriptorOrBuildergetLabelsOrBuilder(int index)The set of labels that are available to describe a specific log entry.java.util.List<? extends LabelDescriptorOrBuilder>getLabelsOrBuilderList()The set of labels that are available to describe a specific log entry.java.lang.StringgetName()The name of the log.com.google.protobuf.ByteStringgetNameBytes()The name of the log.protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()LogDescriptor.BuildermergeFrom(LogDescriptor other)LogDescriptor.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)LogDescriptor.BuildermergeFrom(com.google.protobuf.Message other)LogDescriptor.BuilderremoveLabels(int index)The set of labels that are available to describe a specific log entry.LogDescriptor.BuildersetDescription(java.lang.String value)A human-readable description of this log.LogDescriptor.BuildersetDescriptionBytes(com.google.protobuf.ByteString value)A human-readable description of this log.LogDescriptor.BuildersetDisplayName(java.lang.String value)The human-readable name for this log.LogDescriptor.BuildersetDisplayNameBytes(com.google.protobuf.ByteString value)The human-readable name for this log.LogDescriptor.BuildersetLabels(int index, LabelDescriptor value)The set of labels that are available to describe a specific log entry.LogDescriptor.BuildersetLabels(int index, LabelDescriptor.Builder builderForValue)The set of labels that are available to describe a specific log entry.LogDescriptor.BuildersetName(java.lang.String value)The name of the log.LogDescriptor.BuildersetNameBytes(com.google.protobuf.ByteString value)The name of the log.-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<LogDescriptor.Builder>
-
clear
public LogDescriptor.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<LogDescriptor.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<LogDescriptor.Builder>
-
getDefaultInstanceForType
public LogDescriptor getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public LogDescriptor build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public LogDescriptor buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public LogDescriptor.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<LogDescriptor.Builder>
-
mergeFrom
public LogDescriptor.Builder mergeFrom(LogDescriptor other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<LogDescriptor.Builder>
-
mergeFrom
public LogDescriptor.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<LogDescriptor.Builder>- Throws:
java.io.IOException
-
getName
public java.lang.String getName()
The name of the log. It must be less than 512 characters long and can include the following characters: upper- and lower-case alphanumeric characters [A-Za-z0-9], and punctuation characters including slash, underscore, hyphen, period [/_-.].
string name = 1;- Specified by:
getNamein interfaceLogDescriptorOrBuilder- Returns:
- The name.
-
getNameBytes
public com.google.protobuf.ByteString getNameBytes()
The name of the log. It must be less than 512 characters long and can include the following characters: upper- and lower-case alphanumeric characters [A-Za-z0-9], and punctuation characters including slash, underscore, hyphen, period [/_-.].
string name = 1;- Specified by:
getNameBytesin interfaceLogDescriptorOrBuilder- Returns:
- The bytes for name.
-
setName
public LogDescriptor.Builder setName(java.lang.String value)
The name of the log. It must be less than 512 characters long and can include the following characters: upper- and lower-case alphanumeric characters [A-Za-z0-9], and punctuation characters including slash, underscore, hyphen, period [/_-.].
string name = 1;- Parameters:
value- The name to set.- Returns:
- This builder for chaining.
-
clearName
public LogDescriptor.Builder clearName()
The name of the log. It must be less than 512 characters long and can include the following characters: upper- and lower-case alphanumeric characters [A-Za-z0-9], and punctuation characters including slash, underscore, hyphen, period [/_-.].
string name = 1;- Returns:
- This builder for chaining.
-
setNameBytes
public LogDescriptor.Builder setNameBytes(com.google.protobuf.ByteString value)
The name of the log. It must be less than 512 characters long and can include the following characters: upper- and lower-case alphanumeric characters [A-Za-z0-9], and punctuation characters including slash, underscore, hyphen, period [/_-.].
string name = 1;- Parameters:
value- The bytes for name to set.- Returns:
- This builder for chaining.
-
getLabelsList
public java.util.List<LabelDescriptor> getLabelsList()
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;- Specified by:
getLabelsListin interfaceLogDescriptorOrBuilder
-
getLabelsCount
public int getLabelsCount()
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;- Specified by:
getLabelsCountin interfaceLogDescriptorOrBuilder
-
getLabels
public LabelDescriptor getLabels(int index)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;- Specified by:
getLabelsin interfaceLogDescriptorOrBuilder
-
setLabels
public LogDescriptor.Builder setLabels(int index, LabelDescriptor value)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
setLabels
public LogDescriptor.Builder setLabels(int index, LabelDescriptor.Builder builderForValue)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
addLabels
public LogDescriptor.Builder addLabels(LabelDescriptor value)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
addLabels
public LogDescriptor.Builder addLabels(int index, LabelDescriptor value)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
addLabels
public LogDescriptor.Builder addLabels(LabelDescriptor.Builder builderForValue)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
addLabels
public LogDescriptor.Builder addLabels(int index, LabelDescriptor.Builder builderForValue)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
addAllLabels
public LogDescriptor.Builder addAllLabels(java.lang.Iterable<? extends LabelDescriptor> values)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
clearLabels
public LogDescriptor.Builder clearLabels()
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
removeLabels
public LogDescriptor.Builder removeLabels(int index)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
getLabelsBuilder
public LabelDescriptor.Builder getLabelsBuilder(int index)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
getLabelsOrBuilder
public LabelDescriptorOrBuilder getLabelsOrBuilder(int index)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;- Specified by:
getLabelsOrBuilderin interfaceLogDescriptorOrBuilder
-
getLabelsOrBuilderList
public java.util.List<? extends LabelDescriptorOrBuilder> getLabelsOrBuilderList()
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;- Specified by:
getLabelsOrBuilderListin interfaceLogDescriptorOrBuilder
-
addLabelsBuilder
public LabelDescriptor.Builder addLabelsBuilder()
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
addLabelsBuilder
public LabelDescriptor.Builder addLabelsBuilder(int index)
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
getLabelsBuilderList
public java.util.List<LabelDescriptor.Builder> getLabelsBuilderList()
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
repeated .google.api.LabelDescriptor labels = 2;
-
getDescription
public java.lang.String getDescription()
A human-readable description of this log. This information appears in the documentation and can contain details.
string description = 3;- Specified by:
getDescriptionin interfaceLogDescriptorOrBuilder- Returns:
- The description.
-
getDescriptionBytes
public com.google.protobuf.ByteString getDescriptionBytes()
A human-readable description of this log. This information appears in the documentation and can contain details.
string description = 3;- Specified by:
getDescriptionBytesin interfaceLogDescriptorOrBuilder- Returns:
- The bytes for description.
-
setDescription
public LogDescriptor.Builder setDescription(java.lang.String value)
A human-readable description of this log. This information appears in the documentation and can contain details.
string description = 3;- Parameters:
value- The description to set.- Returns:
- This builder for chaining.
-
clearDescription
public LogDescriptor.Builder clearDescription()
A human-readable description of this log. This information appears in the documentation and can contain details.
string description = 3;- Returns:
- This builder for chaining.
-
setDescriptionBytes
public LogDescriptor.Builder setDescriptionBytes(com.google.protobuf.ByteString value)
A human-readable description of this log. This information appears in the documentation and can contain details.
string description = 3;- Parameters:
value- The bytes for description to set.- Returns:
- This builder for chaining.
-
getDisplayName
public java.lang.String getDisplayName()
The human-readable name for this log. This information appears on the user interface and should be concise.
string display_name = 4;- Specified by:
getDisplayNamein interfaceLogDescriptorOrBuilder- Returns:
- The displayName.
-
getDisplayNameBytes
public com.google.protobuf.ByteString getDisplayNameBytes()
The human-readable name for this log. This information appears on the user interface and should be concise.
string display_name = 4;- Specified by:
getDisplayNameBytesin interfaceLogDescriptorOrBuilder- Returns:
- The bytes for displayName.
-
setDisplayName
public LogDescriptor.Builder setDisplayName(java.lang.String value)
The human-readable name for this log. This information appears on the user interface and should be concise.
string display_name = 4;- Parameters:
value- The displayName to set.- Returns:
- This builder for chaining.
-
clearDisplayName
public LogDescriptor.Builder clearDisplayName()
The human-readable name for this log. This information appears on the user interface and should be concise.
string display_name = 4;- Returns:
- This builder for chaining.
-
setDisplayNameBytes
public LogDescriptor.Builder setDisplayNameBytes(com.google.protobuf.ByteString value)
The human-readable name for this log. This information appears on the user interface and should be concise.
string display_name = 4;- Parameters:
value- The bytes for displayName to set.- Returns:
- This builder for chaining.
-
-