Class Logging

  • All Implemented Interfaces:
    LoggingOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, java.io.Serializable

    public final class Logging
    extends com.google.protobuf.GeneratedMessage
    implements LoggingOrBuilder
     Logging configuration of the service.
    
     The following example shows how to configure logs to be sent to the
     producer and consumer projects. In the example, the `activity_history`
     log is sent to both the producer and consumer projects, whereas the
     `purchase_history` log is only sent to the producer project.
    
     monitored_resources:
     - type: library.googleapis.com/branch
     labels:
     - key: /city
     description: The city where the library branch is located in.
     - key: /name
     description: The name of the branch.
     logs:
     - name: activity_history
     labels:
     - key: /customer_id
     - name: purchase_history
     logging:
     producer_destinations:
     - monitored_resource: library.googleapis.com/branch
     logs:
     - activity_history
     - purchase_history
     consumer_destinations:
     - monitored_resource: library.googleapis.com/branch
     logs:
     - activity_history
     
    Protobuf type google.api.Logging
    See Also:
    Serialized Form
    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      static class  Logging.Builder
      Logging configuration of the service.
      static class  Logging.LoggingDestination
      Configuration of a specific logging destination (the producer project or the consumer project).
      static interface  Logging.LoggingDestinationOrBuilder  
      • Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessage

        com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>,​BuilderT extends com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT,​BuilderT>>, com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.FieldAccessorTable, com.google.protobuf.GeneratedMessage.GeneratedExtension<ContainingT extends com.google.protobuf.Message,​T extends java.lang.Object>, com.google.protobuf.GeneratedMessage.UnusedPrivateParameter
      • Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessage

        com.google.protobuf.AbstractMessage.BuilderParent
      • Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessageLite

        com.google.protobuf.AbstractMessageLite.InternalOneOfEnum
    • Field Summary

      Fields 
      Modifier and Type Field Description
      static int CONSUMER_DESTINATIONS_FIELD_NUMBER  
      static int PRODUCER_DESTINATIONS_FIELD_NUMBER  
      • Fields inherited from class com.google.protobuf.GeneratedMessage

        alwaysUseFieldBuilders, unknownFields
      • Fields inherited from class com.google.protobuf.AbstractMessage

        memoizedSize
      • Fields inherited from class com.google.protobuf.AbstractMessageLite

        memoizedHashCode
    • Field Detail

      • PRODUCER_DESTINATIONS_FIELD_NUMBER

        public static final int PRODUCER_DESTINATIONS_FIELD_NUMBER
        See Also:
        Constant Field Values
      • CONSUMER_DESTINATIONS_FIELD_NUMBER

        public static final int CONSUMER_DESTINATIONS_FIELD_NUMBER
        See Also:
        Constant Field Values
    • Method Detail

      • getDescriptor

        public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
      • internalGetFieldAccessorTable

        protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
        Specified by:
        internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessage
      • getProducerDestinationsList

        public java.util.List<Logging.LoggingDestination> getProducerDestinationsList()
         Logging configurations for sending logs to the producer project.
         There can be multiple producer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one producer destination.
         
        repeated .google.api.Logging.LoggingDestination producer_destinations = 1;
        Specified by:
        getProducerDestinationsList in interface LoggingOrBuilder
      • getProducerDestinationsOrBuilderList

        public java.util.List<? extends Logging.LoggingDestinationOrBuilder> getProducerDestinationsOrBuilderList()
         Logging configurations for sending logs to the producer project.
         There can be multiple producer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one producer destination.
         
        repeated .google.api.Logging.LoggingDestination producer_destinations = 1;
        Specified by:
        getProducerDestinationsOrBuilderList in interface LoggingOrBuilder
      • getProducerDestinationsCount

        public int getProducerDestinationsCount()
         Logging configurations for sending logs to the producer project.
         There can be multiple producer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one producer destination.
         
        repeated .google.api.Logging.LoggingDestination producer_destinations = 1;
        Specified by:
        getProducerDestinationsCount in interface LoggingOrBuilder
      • getProducerDestinations

        public Logging.LoggingDestination getProducerDestinations​(int index)
         Logging configurations for sending logs to the producer project.
         There can be multiple producer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one producer destination.
         
        repeated .google.api.Logging.LoggingDestination producer_destinations = 1;
        Specified by:
        getProducerDestinations in interface LoggingOrBuilder
      • getProducerDestinationsOrBuilder

        public Logging.LoggingDestinationOrBuilder getProducerDestinationsOrBuilder​(int index)
         Logging configurations for sending logs to the producer project.
         There can be multiple producer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one producer destination.
         
        repeated .google.api.Logging.LoggingDestination producer_destinations = 1;
        Specified by:
        getProducerDestinationsOrBuilder in interface LoggingOrBuilder
      • getConsumerDestinationsList

        public java.util.List<Logging.LoggingDestination> getConsumerDestinationsList()
         Logging configurations for sending logs to the consumer project.
         There can be multiple consumer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one consumer destination.
         
        repeated .google.api.Logging.LoggingDestination consumer_destinations = 2;
        Specified by:
        getConsumerDestinationsList in interface LoggingOrBuilder
      • getConsumerDestinationsOrBuilderList

        public java.util.List<? extends Logging.LoggingDestinationOrBuilder> getConsumerDestinationsOrBuilderList()
         Logging configurations for sending logs to the consumer project.
         There can be multiple consumer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one consumer destination.
         
        repeated .google.api.Logging.LoggingDestination consumer_destinations = 2;
        Specified by:
        getConsumerDestinationsOrBuilderList in interface LoggingOrBuilder
      • getConsumerDestinationsCount

        public int getConsumerDestinationsCount()
         Logging configurations for sending logs to the consumer project.
         There can be multiple consumer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one consumer destination.
         
        repeated .google.api.Logging.LoggingDestination consumer_destinations = 2;
        Specified by:
        getConsumerDestinationsCount in interface LoggingOrBuilder
      • getConsumerDestinations

        public Logging.LoggingDestination getConsumerDestinations​(int index)
         Logging configurations for sending logs to the consumer project.
         There can be multiple consumer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one consumer destination.
         
        repeated .google.api.Logging.LoggingDestination consumer_destinations = 2;
        Specified by:
        getConsumerDestinations in interface LoggingOrBuilder
      • getConsumerDestinationsOrBuilder

        public Logging.LoggingDestinationOrBuilder getConsumerDestinationsOrBuilder​(int index)
         Logging configurations for sending logs to the consumer project.
         There can be multiple consumer destinations, each one must have a
         different monitored resource type. A log can be used in at most
         one consumer destination.
         
        repeated .google.api.Logging.LoggingDestination consumer_destinations = 2;
        Specified by:
        getConsumerDestinationsOrBuilder in interface LoggingOrBuilder
      • isInitialized

        public final boolean isInitialized()
        Specified by:
        isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
        Overrides:
        isInitialized in class com.google.protobuf.GeneratedMessage
      • writeTo

        public void writeTo​(com.google.protobuf.CodedOutputStream output)
                     throws java.io.IOException
        Specified by:
        writeTo in interface com.google.protobuf.MessageLite
        Overrides:
        writeTo in class com.google.protobuf.GeneratedMessage
        Throws:
        java.io.IOException
      • getSerializedSize

        public int getSerializedSize()
        Specified by:
        getSerializedSize in interface com.google.protobuf.MessageLite
        Overrides:
        getSerializedSize in class com.google.protobuf.GeneratedMessage
      • equals

        public boolean equals​(java.lang.Object obj)
        Specified by:
        equals in interface com.google.protobuf.Message
        Overrides:
        equals in class com.google.protobuf.AbstractMessage
      • hashCode

        public int hashCode()
        Specified by:
        hashCode in interface com.google.protobuf.Message
        Overrides:
        hashCode in class com.google.protobuf.AbstractMessage
      • parseFrom

        public static Logging parseFrom​(java.nio.ByteBuffer data)
                                 throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Logging parseFrom​(java.nio.ByteBuffer data,
                                        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                 throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Logging parseFrom​(com.google.protobuf.ByteString data)
                                 throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Logging parseFrom​(com.google.protobuf.ByteString data,
                                        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                 throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Logging parseFrom​(byte[] data)
                                 throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Logging parseFrom​(byte[] data,
                                        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                 throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Logging parseFrom​(java.io.InputStream input)
                                 throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static Logging parseFrom​(java.io.InputStream input,
                                        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                 throws java.io.IOException
        Throws:
        java.io.IOException
      • parseDelimitedFrom

        public static Logging parseDelimitedFrom​(java.io.InputStream input)
                                          throws java.io.IOException
        Throws:
        java.io.IOException
      • parseDelimitedFrom

        public static Logging parseDelimitedFrom​(java.io.InputStream input,
                                                 com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                          throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static Logging parseFrom​(com.google.protobuf.CodedInputStream input)
                                 throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static Logging parseFrom​(com.google.protobuf.CodedInputStream input,
                                        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                 throws java.io.IOException
        Throws:
        java.io.IOException
      • newBuilderForType

        public Logging.Builder newBuilderForType()
        Specified by:
        newBuilderForType in interface com.google.protobuf.Message
        Specified by:
        newBuilderForType in interface com.google.protobuf.MessageLite
      • toBuilder

        public Logging.Builder toBuilder()
        Specified by:
        toBuilder in interface com.google.protobuf.Message
        Specified by:
        toBuilder in interface com.google.protobuf.MessageLite
      • newBuilderForType

        protected Logging.Builder newBuilderForType​(com.google.protobuf.AbstractMessage.BuilderParent parent)
        Overrides:
        newBuilderForType in class com.google.protobuf.AbstractMessage
      • getDefaultInstance

        public static Logging getDefaultInstance()
      • parser

        public static com.google.protobuf.Parser<Logging> parser()
      • getParserForType

        public com.google.protobuf.Parser<Logging> getParserForType()
        Specified by:
        getParserForType in interface com.google.protobuf.Message
        Specified by:
        getParserForType in interface com.google.protobuf.MessageLite
        Overrides:
        getParserForType in class com.google.protobuf.GeneratedMessage
      • getDefaultInstanceForType

        public Logging getDefaultInstanceForType()
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder