Package com.google.api
Class Logging.LoggingDestination.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<Logging.LoggingDestination.Builder>
-
- com.google.api.Logging.LoggingDestination.Builder
-
- All Implemented Interfaces:
Logging.LoggingDestinationOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- Logging.LoggingDestination
public static final class Logging.LoggingDestination.Builder extends com.google.protobuf.GeneratedMessage.Builder<Logging.LoggingDestination.Builder> implements Logging.LoggingDestinationOrBuilder
Configuration of a specific logging destination (the producer project or the consumer project).
Protobuf typegoogle.api.Logging.LoggingDestination
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description Logging.LoggingDestination.BuilderaddAllLogs(java.lang.Iterable<java.lang.String> values)Names of the logs to be sent to this destination.Logging.LoggingDestination.BuilderaddLogs(java.lang.String value)Names of the logs to be sent to this destination.Logging.LoggingDestination.BuilderaddLogsBytes(com.google.protobuf.ByteString value)Names of the logs to be sent to this destination.Logging.LoggingDestinationbuild()Logging.LoggingDestinationbuildPartial()Logging.LoggingDestination.Builderclear()Logging.LoggingDestination.BuilderclearLogs()Names of the logs to be sent to this destination.Logging.LoggingDestination.BuilderclearMonitoredResource()The monitored resource type.Logging.LoggingDestinationgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()java.lang.StringgetLogs(int index)Names of the logs to be sent to this destination.com.google.protobuf.ByteStringgetLogsBytes(int index)Names of the logs to be sent to this destination.intgetLogsCount()Names of the logs to be sent to this destination.com.google.protobuf.ProtocolStringListgetLogsList()Names of the logs to be sent to this destination.java.lang.StringgetMonitoredResource()The monitored resource type.com.google.protobuf.ByteStringgetMonitoredResourceBytes()The monitored resource type.protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()Logging.LoggingDestination.BuildermergeFrom(Logging.LoggingDestination other)Logging.LoggingDestination.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)Logging.LoggingDestination.BuildermergeFrom(com.google.protobuf.Message other)Logging.LoggingDestination.BuildersetLogs(int index, java.lang.String value)Names of the logs to be sent to this destination.Logging.LoggingDestination.BuildersetMonitoredResource(java.lang.String value)The monitored resource type.Logging.LoggingDestination.BuildersetMonitoredResourceBytes(com.google.protobuf.ByteString value)The monitored resource type.-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<Logging.LoggingDestination.Builder>
-
clear
public Logging.LoggingDestination.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<Logging.LoggingDestination.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<Logging.LoggingDestination.Builder>
-
getDefaultInstanceForType
public Logging.LoggingDestination getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public Logging.LoggingDestination build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public Logging.LoggingDestination buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public Logging.LoggingDestination.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Logging.LoggingDestination.Builder>
-
mergeFrom
public Logging.LoggingDestination.Builder mergeFrom(Logging.LoggingDestination other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<Logging.LoggingDestination.Builder>
-
mergeFrom
public Logging.LoggingDestination.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Logging.LoggingDestination.Builder>- Throws:
java.io.IOException
-
getMonitoredResource
public java.lang.String getMonitoredResource()
The monitored resource type. The type must be defined in the [Service.monitored_resources][google.api.Service.monitored_resources] section.
string monitored_resource = 3;- Specified by:
getMonitoredResourcein interfaceLogging.LoggingDestinationOrBuilder- Returns:
- The monitoredResource.
-
getMonitoredResourceBytes
public com.google.protobuf.ByteString getMonitoredResourceBytes()
The monitored resource type. The type must be defined in the [Service.monitored_resources][google.api.Service.monitored_resources] section.
string monitored_resource = 3;- Specified by:
getMonitoredResourceBytesin interfaceLogging.LoggingDestinationOrBuilder- Returns:
- The bytes for monitoredResource.
-
setMonitoredResource
public Logging.LoggingDestination.Builder setMonitoredResource(java.lang.String value)
The monitored resource type. The type must be defined in the [Service.monitored_resources][google.api.Service.monitored_resources] section.
string monitored_resource = 3;- Parameters:
value- The monitoredResource to set.- Returns:
- This builder for chaining.
-
clearMonitoredResource
public Logging.LoggingDestination.Builder clearMonitoredResource()
The monitored resource type. The type must be defined in the [Service.monitored_resources][google.api.Service.monitored_resources] section.
string monitored_resource = 3;- Returns:
- This builder for chaining.
-
setMonitoredResourceBytes
public Logging.LoggingDestination.Builder setMonitoredResourceBytes(com.google.protobuf.ByteString value)
The monitored resource type. The type must be defined in the [Service.monitored_resources][google.api.Service.monitored_resources] section.
string monitored_resource = 3;- Parameters:
value- The bytes for monitoredResource to set.- Returns:
- This builder for chaining.
-
getLogsList
public com.google.protobuf.ProtocolStringList getLogsList()
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Specified by:
getLogsListin interfaceLogging.LoggingDestinationOrBuilder- Returns:
- A list containing the logs.
-
getLogsCount
public int getLogsCount()
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Specified by:
getLogsCountin interfaceLogging.LoggingDestinationOrBuilder- Returns:
- The count of logs.
-
getLogs
public java.lang.String getLogs(int index)
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Specified by:
getLogsin interfaceLogging.LoggingDestinationOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The logs at the given index.
-
getLogsBytes
public com.google.protobuf.ByteString getLogsBytes(int index)
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Specified by:
getLogsBytesin interfaceLogging.LoggingDestinationOrBuilder- Parameters:
index- The index of the value to return.- Returns:
- The bytes of the logs at the given index.
-
setLogs
public Logging.LoggingDestination.Builder setLogs(int index, java.lang.String value)
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Parameters:
index- The index to set the value at.value- The logs to set.- Returns:
- This builder for chaining.
-
addLogs
public Logging.LoggingDestination.Builder addLogs(java.lang.String value)
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Parameters:
value- The logs to add.- Returns:
- This builder for chaining.
-
addAllLogs
public Logging.LoggingDestination.Builder addAllLogs(java.lang.Iterable<java.lang.String> values)
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Parameters:
values- The logs to add.- Returns:
- This builder for chaining.
-
clearLogs
public Logging.LoggingDestination.Builder clearLogs()
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Returns:
- This builder for chaining.
-
addLogsBytes
public Logging.LoggingDestination.Builder addLogsBytes(com.google.protobuf.ByteString value)
Names of the logs to be sent to this destination. Each name must be defined in the [Service.logs][google.api.Service.logs] section. If the log name is not a domain scoped name, it will be automatically prefixed with the service name followed by "/".
repeated string logs = 1;- Parameters:
value- The bytes of the logs to add.- Returns:
- This builder for chaining.
-
-