Package com.google.api
Class MethodSettings.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<MethodSettings.Builder>
-
- com.google.api.MethodSettings.Builder
-
- All Implemented Interfaces:
MethodSettingsOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- MethodSettings
public static final class MethodSettings.Builder extends com.google.protobuf.GeneratedMessage.Builder<MethodSettings.Builder> implements MethodSettingsOrBuilder
Describes the generator configuration for a method.
Protobuf typegoogle.api.MethodSettings
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description MethodSettings.BuilderaddAllAutoPopulatedFields(java.lang.Iterable<java.lang.String> values)List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.MethodSettings.BuilderaddAutoPopulatedFields(java.lang.String value)List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.MethodSettings.BuilderaddAutoPopulatedFieldsBytes(com.google.protobuf.ByteString value)List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.MethodSettingsbuild()MethodSettingsbuildPartial()MethodSettings.Builderclear()MethodSettings.BuilderclearAutoPopulatedFields()List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.MethodSettings.BuilderclearLongRunning()Describes settings to use for long-running operations when generating API methods for RPCs.MethodSettings.BuilderclearSelector()The fully qualified name of the method, for which the options below apply.java.lang.StringgetAutoPopulatedFields(int index)List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.com.google.protobuf.ByteStringgetAutoPopulatedFieldsBytes(int index)List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.intgetAutoPopulatedFieldsCount()List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.com.google.protobuf.ProtocolStringListgetAutoPopulatedFieldsList()List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.MethodSettingsgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()MethodSettings.LongRunninggetLongRunning()Describes settings to use for long-running operations when generating API methods for RPCs.MethodSettings.LongRunning.BuildergetLongRunningBuilder()Describes settings to use for long-running operations when generating API methods for RPCs.MethodSettings.LongRunningOrBuildergetLongRunningOrBuilder()Describes settings to use for long-running operations when generating API methods for RPCs.java.lang.StringgetSelector()The fully qualified name of the method, for which the options below apply.com.google.protobuf.ByteStringgetSelectorBytes()The fully qualified name of the method, for which the options below apply.booleanhasLongRunning()Describes settings to use for long-running operations when generating API methods for RPCs.protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()MethodSettings.BuildermergeFrom(MethodSettings other)MethodSettings.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)MethodSettings.BuildermergeFrom(com.google.protobuf.Message other)MethodSettings.BuildermergeLongRunning(MethodSettings.LongRunning value)Describes settings to use for long-running operations when generating API methods for RPCs.MethodSettings.BuildersetAutoPopulatedFields(int index, java.lang.String value)List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.MethodSettings.BuildersetLongRunning(MethodSettings.LongRunning value)Describes settings to use for long-running operations when generating API methods for RPCs.MethodSettings.BuildersetLongRunning(MethodSettings.LongRunning.Builder builderForValue)Describes settings to use for long-running operations when generating API methods for RPCs.MethodSettings.BuildersetSelector(java.lang.String value)The fully qualified name of the method, for which the options below apply.MethodSettings.BuildersetSelectorBytes(com.google.protobuf.ByteString value)The fully qualified name of the method, for which the options below apply.-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<MethodSettings.Builder>
-
clear
public MethodSettings.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<MethodSettings.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<MethodSettings.Builder>
-
getDefaultInstanceForType
public MethodSettings getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public MethodSettings build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public MethodSettings buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public MethodSettings.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<MethodSettings.Builder>
-
mergeFrom
public MethodSettings.Builder mergeFrom(MethodSettings other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<MethodSettings.Builder>
-
mergeFrom
public MethodSettings.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<MethodSettings.Builder>- Throws:
java.io.IOException
-
getSelector
public java.lang.String getSelector()
The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
string selector = 1;- Specified by:
getSelectorin interfaceMethodSettingsOrBuilder- Returns:
- The selector.
-
getSelectorBytes
public com.google.protobuf.ByteString getSelectorBytes()
The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
string selector = 1;- Specified by:
getSelectorBytesin interfaceMethodSettingsOrBuilder- Returns:
- The bytes for selector.
-
setSelector
public MethodSettings.Builder setSelector(java.lang.String value)
The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
string selector = 1;- Parameters:
value- The selector to set.- Returns:
- This builder for chaining.
-
clearSelector
public MethodSettings.Builder clearSelector()
The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
string selector = 1;- Returns:
- This builder for chaining.
-
setSelectorBytes
public MethodSettings.Builder setSelectorBytes(com.google.protobuf.ByteString value)
The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
string selector = 1;- Parameters:
value- The bytes for selector to set.- Returns:
- This builder for chaining.
-
hasLongRunning
public boolean hasLongRunning()
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto. Example of a YAML configuration:: publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes
.google.api.MethodSettings.LongRunning long_running = 2;- Specified by:
hasLongRunningin interfaceMethodSettingsOrBuilder- Returns:
- Whether the longRunning field is set.
-
getLongRunning
public MethodSettings.LongRunning getLongRunning()
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto. Example of a YAML configuration:: publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes
.google.api.MethodSettings.LongRunning long_running = 2;- Specified by:
getLongRunningin interfaceMethodSettingsOrBuilder- Returns:
- The longRunning.
-
setLongRunning
public MethodSettings.Builder setLongRunning(MethodSettings.LongRunning value)
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto. Example of a YAML configuration:: publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes
.google.api.MethodSettings.LongRunning long_running = 2;
-
setLongRunning
public MethodSettings.Builder setLongRunning(MethodSettings.LongRunning.Builder builderForValue)
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto. Example of a YAML configuration:: publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes
.google.api.MethodSettings.LongRunning long_running = 2;
-
mergeLongRunning
public MethodSettings.Builder mergeLongRunning(MethodSettings.LongRunning value)
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto. Example of a YAML configuration:: publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes
.google.api.MethodSettings.LongRunning long_running = 2;
-
clearLongRunning
public MethodSettings.Builder clearLongRunning()
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto. Example of a YAML configuration:: publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes
.google.api.MethodSettings.LongRunning long_running = 2;
-
getLongRunningBuilder
public MethodSettings.LongRunning.Builder getLongRunningBuilder()
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto. Example of a YAML configuration:: publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes
.google.api.MethodSettings.LongRunning long_running = 2;
-
getLongRunningOrBuilder
public MethodSettings.LongRunningOrBuilder getLongRunningOrBuilder()
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto. Example of a YAML configuration:: publishing: method_settings: - selector: google.cloud.speech.v2.Speech.BatchRecognize long_running: initial_poll_delay: seconds: 60 # 1 minute poll_delay_multiplier: 1.5 max_poll_delay: seconds: 360 # 6 minutes total_poll_timeout: seconds: 54000 # 90 minutes
.google.api.MethodSettings.LongRunning long_running = 2;- Specified by:
getLongRunningOrBuilderin interfaceMethodSettingsOrBuilder
-
getAutoPopulatedFieldsList
public com.google.protobuf.ProtocolStringList getAutoPopulatedFieldsList()
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Specified by:
getAutoPopulatedFieldsListin interfaceMethodSettingsOrBuilder- Returns:
- A list containing the autoPopulatedFields.
-
getAutoPopulatedFieldsCount
public int getAutoPopulatedFieldsCount()
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Specified by:
getAutoPopulatedFieldsCountin interfaceMethodSettingsOrBuilder- Returns:
- The count of autoPopulatedFields.
-
getAutoPopulatedFields
public java.lang.String getAutoPopulatedFields(int index)
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Specified by:
getAutoPopulatedFieldsin interfaceMethodSettingsOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The autoPopulatedFields at the given index.
-
getAutoPopulatedFieldsBytes
public com.google.protobuf.ByteString getAutoPopulatedFieldsBytes(int index)
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Specified by:
getAutoPopulatedFieldsBytesin interfaceMethodSettingsOrBuilder- Parameters:
index- The index of the value to return.- Returns:
- The bytes of the autoPopulatedFields at the given index.
-
setAutoPopulatedFields
public MethodSettings.Builder setAutoPopulatedFields(int index, java.lang.String value)
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Parameters:
index- The index to set the value at.value- The autoPopulatedFields to set.- Returns:
- This builder for chaining.
-
addAutoPopulatedFields
public MethodSettings.Builder addAutoPopulatedFields(java.lang.String value)
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Parameters:
value- The autoPopulatedFields to add.- Returns:
- This builder for chaining.
-
addAllAutoPopulatedFields
public MethodSettings.Builder addAllAutoPopulatedFields(java.lang.Iterable<java.lang.String> values)
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Parameters:
values- The autoPopulatedFields to add.- Returns:
- This builder for chaining.
-
clearAutoPopulatedFields
public MethodSettings.Builder clearAutoPopulatedFields()
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Returns:
- This builder for chaining.
-
addAutoPopulatedFieldsBytes
public MethodSettings.Builder addAutoPopulatedFieldsBytes(com.google.protobuf.ByteString value)
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id
repeated string auto_populated_fields = 3;- Parameters:
value- The bytes of the autoPopulatedFields to add.- Returns:
- This builder for chaining.
-
-