Package com.google.api
Class MethodSettings.LongRunning.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<MethodSettings.LongRunning.Builder>
-
- com.google.api.MethodSettings.LongRunning.Builder
-
- All Implemented Interfaces:
MethodSettings.LongRunningOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- MethodSettings.LongRunning
public static final class MethodSettings.LongRunning.Builder extends com.google.protobuf.GeneratedMessage.Builder<MethodSettings.LongRunning.Builder> implements MethodSettings.LongRunningOrBuilder
Describes settings to use when generating API methods that use the long-running operation pattern. All default values below are from those used in the client library generators (e.g. [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)).
Protobuf typegoogle.api.MethodSettings.LongRunning
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description MethodSettings.LongRunningbuild()MethodSettings.LongRunningbuildPartial()MethodSettings.LongRunning.Builderclear()MethodSettings.LongRunning.BuilderclearInitialPollDelay()Initial delay after which the first poll request will be made.MethodSettings.LongRunning.BuilderclearMaxPollDelay()Maximum time between two subsequent poll requests.MethodSettings.LongRunning.BuilderclearPollDelayMultiplier()Multiplier to gradually increase delay between subsequent polls until it reaches max_poll_delay.MethodSettings.LongRunning.BuilderclearTotalPollTimeout()Total polling timeout.MethodSettings.LongRunninggetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()DurationgetInitialPollDelay()Initial delay after which the first poll request will be made.Duration.BuildergetInitialPollDelayBuilder()Initial delay after which the first poll request will be made.DurationOrBuildergetInitialPollDelayOrBuilder()Initial delay after which the first poll request will be made.DurationgetMaxPollDelay()Maximum time between two subsequent poll requests.Duration.BuildergetMaxPollDelayBuilder()Maximum time between two subsequent poll requests.DurationOrBuildergetMaxPollDelayOrBuilder()Maximum time between two subsequent poll requests.floatgetPollDelayMultiplier()Multiplier to gradually increase delay between subsequent polls until it reaches max_poll_delay.DurationgetTotalPollTimeout()Total polling timeout.Duration.BuildergetTotalPollTimeoutBuilder()Total polling timeout.DurationOrBuildergetTotalPollTimeoutOrBuilder()Total polling timeout.booleanhasInitialPollDelay()Initial delay after which the first poll request will be made.booleanhasMaxPollDelay()Maximum time between two subsequent poll requests.booleanhasTotalPollTimeout()Total polling timeout.protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()MethodSettings.LongRunning.BuildermergeFrom(MethodSettings.LongRunning other)MethodSettings.LongRunning.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)MethodSettings.LongRunning.BuildermergeFrom(com.google.protobuf.Message other)MethodSettings.LongRunning.BuildermergeInitialPollDelay(Duration value)Initial delay after which the first poll request will be made.MethodSettings.LongRunning.BuildermergeMaxPollDelay(Duration value)Maximum time between two subsequent poll requests.MethodSettings.LongRunning.BuildermergeTotalPollTimeout(Duration value)Total polling timeout.MethodSettings.LongRunning.BuildersetInitialPollDelay(Duration value)Initial delay after which the first poll request will be made.MethodSettings.LongRunning.BuildersetInitialPollDelay(Duration.Builder builderForValue)Initial delay after which the first poll request will be made.MethodSettings.LongRunning.BuildersetMaxPollDelay(Duration value)Maximum time between two subsequent poll requests.MethodSettings.LongRunning.BuildersetMaxPollDelay(Duration.Builder builderForValue)Maximum time between two subsequent poll requests.MethodSettings.LongRunning.BuildersetPollDelayMultiplier(float value)Multiplier to gradually increase delay between subsequent polls until it reaches max_poll_delay.MethodSettings.LongRunning.BuildersetTotalPollTimeout(Duration value)Total polling timeout.MethodSettings.LongRunning.BuildersetTotalPollTimeout(Duration.Builder builderForValue)Total polling timeout.-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<MethodSettings.LongRunning.Builder>
-
clear
public MethodSettings.LongRunning.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<MethodSettings.LongRunning.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<MethodSettings.LongRunning.Builder>
-
getDefaultInstanceForType
public MethodSettings.LongRunning getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public MethodSettings.LongRunning build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public MethodSettings.LongRunning buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public MethodSettings.LongRunning.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<MethodSettings.LongRunning.Builder>
-
mergeFrom
public MethodSettings.LongRunning.Builder mergeFrom(MethodSettings.LongRunning other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<MethodSettings.LongRunning.Builder>
-
mergeFrom
public MethodSettings.LongRunning.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<MethodSettings.LongRunning.Builder>- Throws:
java.io.IOException
-
hasInitialPollDelay
public boolean hasInitialPollDelay()
Initial delay after which the first poll request will be made. Default value: 5 seconds.
.google.protobuf.Duration initial_poll_delay = 1;- Specified by:
hasInitialPollDelayin interfaceMethodSettings.LongRunningOrBuilder- Returns:
- Whether the initialPollDelay field is set.
-
getInitialPollDelay
public Duration getInitialPollDelay()
Initial delay after which the first poll request will be made. Default value: 5 seconds.
.google.protobuf.Duration initial_poll_delay = 1;- Specified by:
getInitialPollDelayin interfaceMethodSettings.LongRunningOrBuilder- Returns:
- The initialPollDelay.
-
setInitialPollDelay
public MethodSettings.LongRunning.Builder setInitialPollDelay(Duration value)
Initial delay after which the first poll request will be made. Default value: 5 seconds.
.google.protobuf.Duration initial_poll_delay = 1;
-
setInitialPollDelay
public MethodSettings.LongRunning.Builder setInitialPollDelay(Duration.Builder builderForValue)
Initial delay after which the first poll request will be made. Default value: 5 seconds.
.google.protobuf.Duration initial_poll_delay = 1;
-
mergeInitialPollDelay
public MethodSettings.LongRunning.Builder mergeInitialPollDelay(Duration value)
Initial delay after which the first poll request will be made. Default value: 5 seconds.
.google.protobuf.Duration initial_poll_delay = 1;
-
clearInitialPollDelay
public MethodSettings.LongRunning.Builder clearInitialPollDelay()
Initial delay after which the first poll request will be made. Default value: 5 seconds.
.google.protobuf.Duration initial_poll_delay = 1;
-
getInitialPollDelayBuilder
public Duration.Builder getInitialPollDelayBuilder()
Initial delay after which the first poll request will be made. Default value: 5 seconds.
.google.protobuf.Duration initial_poll_delay = 1;
-
getInitialPollDelayOrBuilder
public DurationOrBuilder getInitialPollDelayOrBuilder()
Initial delay after which the first poll request will be made. Default value: 5 seconds.
.google.protobuf.Duration initial_poll_delay = 1;- Specified by:
getInitialPollDelayOrBuilderin interfaceMethodSettings.LongRunningOrBuilder
-
getPollDelayMultiplier
public float getPollDelayMultiplier()
Multiplier to gradually increase delay between subsequent polls until it reaches max_poll_delay. Default value: 1.5.
float poll_delay_multiplier = 2;- Specified by:
getPollDelayMultiplierin interfaceMethodSettings.LongRunningOrBuilder- Returns:
- The pollDelayMultiplier.
-
setPollDelayMultiplier
public MethodSettings.LongRunning.Builder setPollDelayMultiplier(float value)
Multiplier to gradually increase delay between subsequent polls until it reaches max_poll_delay. Default value: 1.5.
float poll_delay_multiplier = 2;- Parameters:
value- The pollDelayMultiplier to set.- Returns:
- This builder for chaining.
-
clearPollDelayMultiplier
public MethodSettings.LongRunning.Builder clearPollDelayMultiplier()
Multiplier to gradually increase delay between subsequent polls until it reaches max_poll_delay. Default value: 1.5.
float poll_delay_multiplier = 2;- Returns:
- This builder for chaining.
-
hasMaxPollDelay
public boolean hasMaxPollDelay()
Maximum time between two subsequent poll requests. Default value: 45 seconds.
.google.protobuf.Duration max_poll_delay = 3;- Specified by:
hasMaxPollDelayin interfaceMethodSettings.LongRunningOrBuilder- Returns:
- Whether the maxPollDelay field is set.
-
getMaxPollDelay
public Duration getMaxPollDelay()
Maximum time between two subsequent poll requests. Default value: 45 seconds.
.google.protobuf.Duration max_poll_delay = 3;- Specified by:
getMaxPollDelayin interfaceMethodSettings.LongRunningOrBuilder- Returns:
- The maxPollDelay.
-
setMaxPollDelay
public MethodSettings.LongRunning.Builder setMaxPollDelay(Duration value)
Maximum time between two subsequent poll requests. Default value: 45 seconds.
.google.protobuf.Duration max_poll_delay = 3;
-
setMaxPollDelay
public MethodSettings.LongRunning.Builder setMaxPollDelay(Duration.Builder builderForValue)
Maximum time between two subsequent poll requests. Default value: 45 seconds.
.google.protobuf.Duration max_poll_delay = 3;
-
mergeMaxPollDelay
public MethodSettings.LongRunning.Builder mergeMaxPollDelay(Duration value)
Maximum time between two subsequent poll requests. Default value: 45 seconds.
.google.protobuf.Duration max_poll_delay = 3;
-
clearMaxPollDelay
public MethodSettings.LongRunning.Builder clearMaxPollDelay()
Maximum time between two subsequent poll requests. Default value: 45 seconds.
.google.protobuf.Duration max_poll_delay = 3;
-
getMaxPollDelayBuilder
public Duration.Builder getMaxPollDelayBuilder()
Maximum time between two subsequent poll requests. Default value: 45 seconds.
.google.protobuf.Duration max_poll_delay = 3;
-
getMaxPollDelayOrBuilder
public DurationOrBuilder getMaxPollDelayOrBuilder()
Maximum time between two subsequent poll requests. Default value: 45 seconds.
.google.protobuf.Duration max_poll_delay = 3;- Specified by:
getMaxPollDelayOrBuilderin interfaceMethodSettings.LongRunningOrBuilder
-
hasTotalPollTimeout
public boolean hasTotalPollTimeout()
Total polling timeout. Default value: 5 minutes.
.google.protobuf.Duration total_poll_timeout = 4;- Specified by:
hasTotalPollTimeoutin interfaceMethodSettings.LongRunningOrBuilder- Returns:
- Whether the totalPollTimeout field is set.
-
getTotalPollTimeout
public Duration getTotalPollTimeout()
Total polling timeout. Default value: 5 minutes.
.google.protobuf.Duration total_poll_timeout = 4;- Specified by:
getTotalPollTimeoutin interfaceMethodSettings.LongRunningOrBuilder- Returns:
- The totalPollTimeout.
-
setTotalPollTimeout
public MethodSettings.LongRunning.Builder setTotalPollTimeout(Duration value)
Total polling timeout. Default value: 5 minutes.
.google.protobuf.Duration total_poll_timeout = 4;
-
setTotalPollTimeout
public MethodSettings.LongRunning.Builder setTotalPollTimeout(Duration.Builder builderForValue)
Total polling timeout. Default value: 5 minutes.
.google.protobuf.Duration total_poll_timeout = 4;
-
mergeTotalPollTimeout
public MethodSettings.LongRunning.Builder mergeTotalPollTimeout(Duration value)
Total polling timeout. Default value: 5 minutes.
.google.protobuf.Duration total_poll_timeout = 4;
-
clearTotalPollTimeout
public MethodSettings.LongRunning.Builder clearTotalPollTimeout()
Total polling timeout. Default value: 5 minutes.
.google.protobuf.Duration total_poll_timeout = 4;
-
getTotalPollTimeoutBuilder
public Duration.Builder getTotalPollTimeoutBuilder()
Total polling timeout. Default value: 5 minutes.
.google.protobuf.Duration total_poll_timeout = 4;
-
getTotalPollTimeoutOrBuilder
public DurationOrBuilder getTotalPollTimeoutOrBuilder()
Total polling timeout. Default value: 5 minutes.
.google.protobuf.Duration total_poll_timeout = 4;- Specified by:
getTotalPollTimeoutOrBuilderin interfaceMethodSettings.LongRunningOrBuilder
-
-