Class MonitoredResource

  • All Implemented Interfaces:
    MonitoredResourceOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, java.io.Serializable

    public final class MonitoredResource
    extends com.google.protobuf.GeneratedMessage
    implements MonitoredResourceOrBuilder
     An object representing a resource that can be used for monitoring, logging,
     billing, or other purposes. Examples include virtual machine instances,
     databases, and storage devices such as disks. The `type` field identifies a
     [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] object
     that describes the resource's schema. Information in the `labels` field
     identifies the actual resource and its attributes according to the schema.
     For example, a particular Compute Engine VM instance could be represented by
     the following object, because the
     [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] for
     `"gce_instance"` has labels
     `"project_id"`, `"instance_id"` and `"zone"`:
    
     { "type": "gce_instance",
     "labels": { "project_id": "my-project",
     "instance_id": "12345678901234",
     "zone": "us-central1-a" }}
     
    Protobuf type google.api.MonitoredResource
    See Also:
    Serialized Form
    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      static class  MonitoredResource.Builder
      An object representing a resource that can be used for monitoring, logging, billing, or other purposes.
      • Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessage

        com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>,​BuilderT extends com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT,​BuilderT>>, com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.FieldAccessorTable, com.google.protobuf.GeneratedMessage.GeneratedExtension<ContainingT extends com.google.protobuf.Message,​T extends java.lang.Object>, com.google.protobuf.GeneratedMessage.UnusedPrivateParameter
      • Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessage

        com.google.protobuf.AbstractMessage.BuilderParent
      • Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessageLite

        com.google.protobuf.AbstractMessageLite.InternalOneOfEnum
    • Field Summary

      Fields 
      Modifier and Type Field Description
      static int LABELS_FIELD_NUMBER  
      static int TYPE_FIELD_NUMBER  
      • Fields inherited from class com.google.protobuf.GeneratedMessage

        alwaysUseFieldBuilders, unknownFields
      • Fields inherited from class com.google.protobuf.AbstractMessage

        memoizedSize
      • Fields inherited from class com.google.protobuf.AbstractMessageLite

        memoizedHashCode
    • Method Detail

      • getDescriptor

        public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
      • internalGetMapFieldReflection

        protected com.google.protobuf.MapFieldReflectionAccessor internalGetMapFieldReflection​(int number)
        Overrides:
        internalGetMapFieldReflection in class com.google.protobuf.GeneratedMessage
      • internalGetFieldAccessorTable

        protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
        Specified by:
        internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessage
      • getType

        public java.lang.String getType()
         Required. The monitored resource type. This field must match
         the `type` field of a
         [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor]
         object. For example, the type of a Compute Engine VM instance is
         `gce_instance`. Some descriptors include the service name in the type; for
         example, the type of a Datastream stream is
         `datastream.googleapis.com/Stream`.
         
        string type = 1;
        Specified by:
        getType in interface MonitoredResourceOrBuilder
        Returns:
        The type.
      • getTypeBytes

        public com.google.protobuf.ByteString getTypeBytes()
         Required. The monitored resource type. This field must match
         the `type` field of a
         [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor]
         object. For example, the type of a Compute Engine VM instance is
         `gce_instance`. Some descriptors include the service name in the type; for
         example, the type of a Datastream stream is
         `datastream.googleapis.com/Stream`.
         
        string type = 1;
        Specified by:
        getTypeBytes in interface MonitoredResourceOrBuilder
        Returns:
        The bytes for type.
      • getLabelsCount

        public int getLabelsCount()
        Description copied from interface: MonitoredResourceOrBuilder
         Required. Values for all of the labels listed in the associated monitored
         resource descriptor. For example, Compute Engine VM instances use the
         labels `"project_id"`, `"instance_id"`, and `"zone"`.
         
        map<string, string> labels = 2;
        Specified by:
        getLabelsCount in interface MonitoredResourceOrBuilder
      • containsLabels

        public boolean containsLabels​(java.lang.String key)
         Required. Values for all of the labels listed in the associated monitored
         resource descriptor. For example, Compute Engine VM instances use the
         labels `"project_id"`, `"instance_id"`, and `"zone"`.
         
        map<string, string> labels = 2;
        Specified by:
        containsLabels in interface MonitoredResourceOrBuilder
      • getLabelsMap

        public java.util.Map<java.lang.String,​java.lang.String> getLabelsMap()
         Required. Values for all of the labels listed in the associated monitored
         resource descriptor. For example, Compute Engine VM instances use the
         labels `"project_id"`, `"instance_id"`, and `"zone"`.
         
        map<string, string> labels = 2;
        Specified by:
        getLabelsMap in interface MonitoredResourceOrBuilder
      • getLabelsOrDefault

        public java.lang.String getLabelsOrDefault​(java.lang.String key,
                                                   java.lang.String defaultValue)
         Required. Values for all of the labels listed in the associated monitored
         resource descriptor. For example, Compute Engine VM instances use the
         labels `"project_id"`, `"instance_id"`, and `"zone"`.
         
        map<string, string> labels = 2;
        Specified by:
        getLabelsOrDefault in interface MonitoredResourceOrBuilder
      • getLabelsOrThrow

        public java.lang.String getLabelsOrThrow​(java.lang.String key)
         Required. Values for all of the labels listed in the associated monitored
         resource descriptor. For example, Compute Engine VM instances use the
         labels `"project_id"`, `"instance_id"`, and `"zone"`.
         
        map<string, string> labels = 2;
        Specified by:
        getLabelsOrThrow in interface MonitoredResourceOrBuilder
      • isInitialized

        public final boolean isInitialized()
        Specified by:
        isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
        Overrides:
        isInitialized in class com.google.protobuf.GeneratedMessage
      • writeTo

        public void writeTo​(com.google.protobuf.CodedOutputStream output)
                     throws java.io.IOException
        Specified by:
        writeTo in interface com.google.protobuf.MessageLite
        Overrides:
        writeTo in class com.google.protobuf.GeneratedMessage
        Throws:
        java.io.IOException
      • getSerializedSize

        public int getSerializedSize()
        Specified by:
        getSerializedSize in interface com.google.protobuf.MessageLite
        Overrides:
        getSerializedSize in class com.google.protobuf.GeneratedMessage
      • equals

        public boolean equals​(java.lang.Object obj)
        Specified by:
        equals in interface com.google.protobuf.Message
        Overrides:
        equals in class com.google.protobuf.AbstractMessage
      • hashCode

        public int hashCode()
        Specified by:
        hashCode in interface com.google.protobuf.Message
        Overrides:
        hashCode in class com.google.protobuf.AbstractMessage
      • parseFrom

        public static MonitoredResource parseFrom​(java.nio.ByteBuffer data)
                                           throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static MonitoredResource parseFrom​(java.nio.ByteBuffer data,
                                                  com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                           throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static MonitoredResource parseFrom​(com.google.protobuf.ByteString data)
                                           throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static MonitoredResource parseFrom​(com.google.protobuf.ByteString data,
                                                  com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                           throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static MonitoredResource parseFrom​(byte[] data)
                                           throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static MonitoredResource parseFrom​(byte[] data,
                                                  com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                           throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static MonitoredResource parseFrom​(java.io.InputStream input)
                                           throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static MonitoredResource parseFrom​(java.io.InputStream input,
                                                  com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                           throws java.io.IOException
        Throws:
        java.io.IOException
      • parseDelimitedFrom

        public static MonitoredResource parseDelimitedFrom​(java.io.InputStream input)
                                                    throws java.io.IOException
        Throws:
        java.io.IOException
      • parseDelimitedFrom

        public static MonitoredResource parseDelimitedFrom​(java.io.InputStream input,
                                                           com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                    throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static MonitoredResource parseFrom​(com.google.protobuf.CodedInputStream input)
                                           throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static MonitoredResource parseFrom​(com.google.protobuf.CodedInputStream input,
                                                  com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                           throws java.io.IOException
        Throws:
        java.io.IOException
      • newBuilderForType

        public MonitoredResource.Builder newBuilderForType()
        Specified by:
        newBuilderForType in interface com.google.protobuf.Message
        Specified by:
        newBuilderForType in interface com.google.protobuf.MessageLite
      • toBuilder

        public MonitoredResource.Builder toBuilder()
        Specified by:
        toBuilder in interface com.google.protobuf.Message
        Specified by:
        toBuilder in interface com.google.protobuf.MessageLite
      • newBuilderForType

        protected MonitoredResource.Builder newBuilderForType​(com.google.protobuf.AbstractMessage.BuilderParent parent)
        Overrides:
        newBuilderForType in class com.google.protobuf.AbstractMessage
      • getParserForType

        public com.google.protobuf.Parser<MonitoredResource> getParserForType()
        Specified by:
        getParserForType in interface com.google.protobuf.Message
        Specified by:
        getParserForType in interface com.google.protobuf.MessageLite
        Overrides:
        getParserForType in class com.google.protobuf.GeneratedMessage
      • getDefaultInstanceForType

        public MonitoredResource getDefaultInstanceForType()
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder