Interface ResourceReferenceOrBuilder

  • All Superinterfaces:
    com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder
    All Known Implementing Classes:
    ResourceReference, ResourceReference.Builder

    public interface ResourceReferenceOrBuilder
    extends com.google.protobuf.MessageOrBuilder
    • Method Summary

      All Methods Instance Methods Abstract Methods 
      Modifier and Type Method Description
      java.lang.String getChildType()
      The resource type of a child collection that the annotated field references.
      com.google.protobuf.ByteString getChildTypeBytes()
      The resource type of a child collection that the annotated field references.
      java.lang.String getType()
      The resource type that the annotated field references.
      com.google.protobuf.ByteString getTypeBytes()
      The resource type that the annotated field references.
      • Methods inherited from interface com.google.protobuf.MessageLiteOrBuilder

        isInitialized
      • Methods inherited from interface com.google.protobuf.MessageOrBuilder

        findInitializationErrors, getAllFields, getDefaultInstanceForType, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
    • Method Detail

      • getType

        java.lang.String getType()
         The resource type that the annotated field references.
        
         Example:
        
         message Subscription {
         string topic = 2 [(google.api.resource_reference) = {
         type: "pubsub.googleapis.com/Topic"
         }];
         }
        
         Occasionally, a field may reference an arbitrary resource. In this case,
         APIs use the special value * in their resource reference.
        
         Example:
        
         message GetIamPolicyRequest {
         string resource = 2 [(google.api.resource_reference) = {
         type: "*"
         }];
         }
         
        string type = 1;
        Returns:
        The type.
      • getTypeBytes

        com.google.protobuf.ByteString getTypeBytes()
         The resource type that the annotated field references.
        
         Example:
        
         message Subscription {
         string topic = 2 [(google.api.resource_reference) = {
         type: "pubsub.googleapis.com/Topic"
         }];
         }
        
         Occasionally, a field may reference an arbitrary resource. In this case,
         APIs use the special value * in their resource reference.
        
         Example:
        
         message GetIamPolicyRequest {
         string resource = 2 [(google.api.resource_reference) = {
         type: "*"
         }];
         }
         
        string type = 1;
        Returns:
        The bytes for type.
      • getChildType

        java.lang.String getChildType()
         The resource type of a child collection that the annotated field
         references. This is useful for annotating the `parent` field that
         doesn't have a fixed resource type.
        
         Example:
        
         message ListLogEntriesRequest {
         string parent = 1 [(google.api.resource_reference) = {
         child_type: "logging.googleapis.com/LogEntry"
         };
         }
         
        string child_type = 2;
        Returns:
        The childType.
      • getChildTypeBytes

        com.google.protobuf.ByteString getChildTypeBytes()
         The resource type of a child collection that the annotated field
         references. This is useful for annotating the `parent` field that
         doesn't have a fixed resource type.
        
         Example:
        
         message ListLogEntriesRequest {
         string parent = 1 [(google.api.resource_reference) = {
         child_type: "logging.googleapis.com/LogEntry"
         };
         }
         
        string child_type = 2;
        Returns:
        The bytes for childType.