Package com.google.api
Class SystemParameterRule.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<SystemParameterRule.Builder>
-
- com.google.api.SystemParameterRule.Builder
-
- All Implemented Interfaces:
SystemParameterRuleOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- SystemParameterRule
public static final class SystemParameterRule.Builder extends com.google.protobuf.GeneratedMessage.Builder<SystemParameterRule.Builder> implements SystemParameterRuleOrBuilder
Define a system parameter rule mapping system parameter definitions to methods.
Protobuf typegoogle.api.SystemParameterRule
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description SystemParameterRule.BuilderaddAllParameters(java.lang.Iterable<? extends SystemParameter> values)Define parameters.SystemParameterRule.BuilderaddParameters(int index, SystemParameter value)Define parameters.SystemParameterRule.BuilderaddParameters(int index, SystemParameter.Builder builderForValue)Define parameters.SystemParameterRule.BuilderaddParameters(SystemParameter value)Define parameters.SystemParameterRule.BuilderaddParameters(SystemParameter.Builder builderForValue)Define parameters.SystemParameter.BuilderaddParametersBuilder()Define parameters.SystemParameter.BuilderaddParametersBuilder(int index)Define parameters.SystemParameterRulebuild()SystemParameterRulebuildPartial()SystemParameterRule.Builderclear()SystemParameterRule.BuilderclearParameters()Define parameters.SystemParameterRule.BuilderclearSelector()Selects the methods to which this rule applies.SystemParameterRulegetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()SystemParametergetParameters(int index)Define parameters.SystemParameter.BuildergetParametersBuilder(int index)Define parameters.java.util.List<SystemParameter.Builder>getParametersBuilderList()Define parameters.intgetParametersCount()Define parameters.java.util.List<SystemParameter>getParametersList()Define parameters.SystemParameterOrBuildergetParametersOrBuilder(int index)Define parameters.java.util.List<? extends SystemParameterOrBuilder>getParametersOrBuilderList()Define parameters.java.lang.StringgetSelector()Selects the methods to which this rule applies.com.google.protobuf.ByteStringgetSelectorBytes()Selects the methods to which this rule applies.protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()SystemParameterRule.BuildermergeFrom(SystemParameterRule other)SystemParameterRule.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)SystemParameterRule.BuildermergeFrom(com.google.protobuf.Message other)SystemParameterRule.BuilderremoveParameters(int index)Define parameters.SystemParameterRule.BuildersetParameters(int index, SystemParameter value)Define parameters.SystemParameterRule.BuildersetParameters(int index, SystemParameter.Builder builderForValue)Define parameters.SystemParameterRule.BuildersetSelector(java.lang.String value)Selects the methods to which this rule applies.SystemParameterRule.BuildersetSelectorBytes(com.google.protobuf.ByteString value)Selects the methods to which this rule applies.-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<SystemParameterRule.Builder>
-
clear
public SystemParameterRule.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<SystemParameterRule.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<SystemParameterRule.Builder>
-
getDefaultInstanceForType
public SystemParameterRule getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public SystemParameterRule build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public SystemParameterRule buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public SystemParameterRule.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<SystemParameterRule.Builder>
-
mergeFrom
public SystemParameterRule.Builder mergeFrom(SystemParameterRule other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<SystemParameterRule.Builder>
-
mergeFrom
public SystemParameterRule.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<SystemParameterRule.Builder>- Throws:
java.io.IOException
-
getSelector
public java.lang.String getSelector()
Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs. Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
string selector = 1;- Specified by:
getSelectorin interfaceSystemParameterRuleOrBuilder- Returns:
- The selector.
-
getSelectorBytes
public com.google.protobuf.ByteString getSelectorBytes()
Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs. Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
string selector = 1;- Specified by:
getSelectorBytesin interfaceSystemParameterRuleOrBuilder- Returns:
- The bytes for selector.
-
setSelector
public SystemParameterRule.Builder setSelector(java.lang.String value)
Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs. Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
string selector = 1;- Parameters:
value- The selector to set.- Returns:
- This builder for chaining.
-
clearSelector
public SystemParameterRule.Builder clearSelector()
Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs. Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
string selector = 1;- Returns:
- This builder for chaining.
-
setSelectorBytes
public SystemParameterRule.Builder setSelectorBytes(com.google.protobuf.ByteString value)
Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs. Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
string selector = 1;- Parameters:
value- The bytes for selector to set.- Returns:
- This builder for chaining.
-
getParametersList
public java.util.List<SystemParameter> getParametersList()
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;- Specified by:
getParametersListin interfaceSystemParameterRuleOrBuilder
-
getParametersCount
public int getParametersCount()
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;- Specified by:
getParametersCountin interfaceSystemParameterRuleOrBuilder
-
getParameters
public SystemParameter getParameters(int index)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;- Specified by:
getParametersin interfaceSystemParameterRuleOrBuilder
-
setParameters
public SystemParameterRule.Builder setParameters(int index, SystemParameter value)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
setParameters
public SystemParameterRule.Builder setParameters(int index, SystemParameter.Builder builderForValue)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
addParameters
public SystemParameterRule.Builder addParameters(SystemParameter value)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
addParameters
public SystemParameterRule.Builder addParameters(int index, SystemParameter value)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
addParameters
public SystemParameterRule.Builder addParameters(SystemParameter.Builder builderForValue)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
addParameters
public SystemParameterRule.Builder addParameters(int index, SystemParameter.Builder builderForValue)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
addAllParameters
public SystemParameterRule.Builder addAllParameters(java.lang.Iterable<? extends SystemParameter> values)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
clearParameters
public SystemParameterRule.Builder clearParameters()
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
removeParameters
public SystemParameterRule.Builder removeParameters(int index)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
getParametersBuilder
public SystemParameter.Builder getParametersBuilder(int index)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
getParametersOrBuilder
public SystemParameterOrBuilder getParametersOrBuilder(int index)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;- Specified by:
getParametersOrBuilderin interfaceSystemParameterRuleOrBuilder
-
getParametersOrBuilderList
public java.util.List<? extends SystemParameterOrBuilder> getParametersOrBuilderList()
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;- Specified by:
getParametersOrBuilderListin interfaceSystemParameterRuleOrBuilder
-
addParametersBuilder
public SystemParameter.Builder addParametersBuilder()
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
addParametersBuilder
public SystemParameter.Builder addParametersBuilder(int index)
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
getParametersBuilderList
public java.util.List<SystemParameter.Builder> getParametersBuilderList()
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
repeated .google.api.SystemParameter parameters = 2;
-
-