Class OperationsGrpc.OperationsImplBase

  • All Implemented Interfaces:
    OperationsGrpc.AsyncService, io.grpc.BindableService
    Enclosing class:
    OperationsGrpc

    public abstract static class OperationsGrpc.OperationsImplBase
    extends java.lang.Object
    implements io.grpc.BindableService, OperationsGrpc.AsyncService
    Base class for the server implementation of the service Operations.
     Manages long-running operations with an API service.
     When an API method normally takes long time to complete, it can be designed
     to return [Operation][google.longrunning.Operation] to the client, and the client can use this
     interface to receive the real response asynchronously by polling the
     operation resource, or pass the operation resource to another API (such as
     Google Cloud Pub/Sub API) to receive the response.  Any API service that
     returns long-running operations should implement the `Operations` interface
     so developers can have a consistent client experience.
     
    • Constructor Detail

      • OperationsImplBase

        public OperationsImplBase()
    • Method Detail

      • bindService

        public final io.grpc.ServerServiceDefinition bindService()
        Specified by:
        bindService in interface io.grpc.BindableService