Package com.google.protobuf
Class DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessage
-
- com.google.protobuf.DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault
-
- All Implemented Interfaces:
DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefaultOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.io.Serializable
- Enclosing class:
- DescriptorProtos.FeatureSetDefaults
public static final class DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault extends com.google.protobuf.GeneratedMessage implements DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefaultOrBuilder
A map from every known edition with a unique set of defaults to its defaults. Not all editions may be contained here. For a given edition, the defaults at the closest matching edition ordered at or before it should be used. This field must be in strict ascending order by edition.
Protobuf typegoogle.protobuf.FeatureSetDefaults.FeatureSetEditionDefault- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classDescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault.BuilderA map from every known edition with a unique set of defaults to its defaults.-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessage
com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.FieldAccessorTable, com.google.protobuf.GeneratedMessage.GeneratedExtension<ContainingT extends com.google.protobuf.Message,T extends java.lang.Object>, com.google.protobuf.GeneratedMessage.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intEDITION_FIELD_NUMBERstatic intFEATURES_FIELD_NUMBER
-
Method Summary
-
Methods inherited from class com.google.protobuf.GeneratedMessage
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, newFileScopedGeneratedExtension, newInstance, newMessageScopedGeneratedExtension, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashFields, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
EDITION_FIELD_NUMBER
public static final int EDITION_FIELD_NUMBER
- See Also:
- Constant Field Values
-
FEATURES_FIELD_NUMBER
public static final int FEATURES_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage
-
hasEdition
public boolean hasEdition()
optional .google.protobuf.Edition edition = 3;- Specified by:
hasEditionin interfaceDescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefaultOrBuilder- Returns:
- Whether the edition field is set.
-
getEdition
public DescriptorProtos.Edition getEdition()
optional .google.protobuf.Edition edition = 3;- Specified by:
getEditionin interfaceDescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefaultOrBuilder- Returns:
- The edition.
-
hasFeatures
public boolean hasFeatures()
optional .google.protobuf.FeatureSet features = 2;- Specified by:
hasFeaturesin interfaceDescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefaultOrBuilder- Returns:
- Whether the features field is set.
-
getFeatures
public DescriptorProtos.FeatureSet getFeatures()
optional .google.protobuf.FeatureSet features = 2;- Specified by:
getFeaturesin interfaceDescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefaultOrBuilder- Returns:
- The features.
-
getFeaturesOrBuilder
public DescriptorProtos.FeatureSetOrBuilder getFeaturesOrBuilder()
optional .google.protobuf.FeatureSet features = 2;- Specified by:
getFeaturesOrBuilderin interfaceDescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefaultOrBuilder
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws java.io.IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessage- Throws:
java.io.IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessage
-
equals
public boolean equals(java.lang.Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(java.nio.ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(java.nio.ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(java.io.InputStream input) throws java.io.IOException
- Throws:
java.io.IOException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(java.io.InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Throws:
java.io.IOException
-
parseDelimitedFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseDelimitedFrom(java.io.InputStream input) throws java.io.IOException
- Throws:
java.io.IOException
-
parseDelimitedFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseDelimitedFrom(java.io.InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Throws:
java.io.IOException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(com.google.protobuf.CodedInputStream input) throws java.io.IOException
- Throws:
java.io.IOException
-
parseFrom
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Throws:
java.io.IOException
-
newBuilderForType
public DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault.Builder newBuilder()
-
newBuilder
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault.Builder newBuilder(DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault prototype)
-
toBuilder
public DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault.Builder newBuilderForType(com.google.protobuf.AbstractMessage.BuilderParent parent)
- Overrides:
newBuilderForTypein classcom.google.protobuf.AbstractMessage
-
getDefaultInstance
public static DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault> parser()
-
getParserForType
public com.google.protobuf.Parser<DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessage
-
getDefaultInstanceForType
public DescriptorProtos.FeatureSetDefaults.FeatureSetEditionDefault getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-