Class JavaFeaturesProto.JavaFeatures

    • Field Detail

      • LEGACY_CLOSED_ENUM_FIELD_NUMBER

        public static final int LEGACY_CLOSED_ENUM_FIELD_NUMBER
        See Also:
        Constant Field Values
      • UTF8_VALIDATION_FIELD_NUMBER

        public static final int UTF8_VALIDATION_FIELD_NUMBER
        See Also:
        Constant Field Values
    • Method Detail

      • getDescriptor

        public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
      • internalGetFieldAccessorTable

        protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
        Specified by:
        internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessage
      • hasLegacyClosedEnum

        public boolean hasLegacyClosedEnum()
         Whether or not to treat an enum field as closed.  This option is only
         applicable to enum fields, and will be removed in the future.  It is
         consistent with the legacy behavior of using proto3 enum types for proto2
         fields.
         
        optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Specified by:
        hasLegacyClosedEnum in interface JavaFeaturesProto.JavaFeaturesOrBuilder
        Returns:
        Whether the legacyClosedEnum field is set.
      • getLegacyClosedEnum

        public boolean getLegacyClosedEnum()
         Whether or not to treat an enum field as closed.  This option is only
         applicable to enum fields, and will be removed in the future.  It is
         consistent with the legacy behavior of using proto3 enum types for proto2
         fields.
         
        optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Specified by:
        getLegacyClosedEnum in interface JavaFeaturesProto.JavaFeaturesOrBuilder
        Returns:
        The legacyClosedEnum.
      • hasUtf8Validation

        public boolean hasUtf8Validation()
        optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Specified by:
        hasUtf8Validation in interface JavaFeaturesProto.JavaFeaturesOrBuilder
        Returns:
        Whether the utf8Validation field is set.
      • isInitialized

        public final boolean isInitialized()
        Specified by:
        isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
        Overrides:
        isInitialized in class com.google.protobuf.GeneratedMessage
      • writeTo

        public void writeTo​(com.google.protobuf.CodedOutputStream output)
                     throws java.io.IOException
        Specified by:
        writeTo in interface com.google.protobuf.MessageLite
        Overrides:
        writeTo in class com.google.protobuf.GeneratedMessage
        Throws:
        java.io.IOException
      • getSerializedSize

        public int getSerializedSize()
        Specified by:
        getSerializedSize in interface com.google.protobuf.MessageLite
        Overrides:
        getSerializedSize in class com.google.protobuf.GeneratedMessage
      • equals

        public boolean equals​(java.lang.Object obj)
        Specified by:
        equals in interface com.google.protobuf.Message
        Overrides:
        equals in class com.google.protobuf.AbstractMessage
      • hashCode

        public int hashCode()
        Specified by:
        hashCode in interface com.google.protobuf.Message
        Overrides:
        hashCode in class com.google.protobuf.AbstractMessage
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(java.nio.ByteBuffer data)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(java.nio.ByteBuffer data,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(com.google.protobuf.ByteString data)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(com.google.protobuf.ByteString data,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(byte[] data)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(byte[] data,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(java.io.InputStream input)
                                                        throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(java.io.InputStream input,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws java.io.IOException
        Throws:
        java.io.IOException
      • parseDelimitedFrom

        public static JavaFeaturesProto.JavaFeatures parseDelimitedFrom​(java.io.InputStream input)
                                                                 throws java.io.IOException
        Throws:
        java.io.IOException
      • parseDelimitedFrom

        public static JavaFeaturesProto.JavaFeatures parseDelimitedFrom​(java.io.InputStream input,
                                                                        com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                                 throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(com.google.protobuf.CodedInputStream input)
                                                        throws java.io.IOException
        Throws:
        java.io.IOException
      • parseFrom

        public static JavaFeaturesProto.JavaFeatures parseFrom​(com.google.protobuf.CodedInputStream input,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws java.io.IOException
        Throws:
        java.io.IOException
      • newBuilderForType

        public JavaFeaturesProto.JavaFeatures.Builder newBuilderForType()
        Specified by:
        newBuilderForType in interface com.google.protobuf.Message
        Specified by:
        newBuilderForType in interface com.google.protobuf.MessageLite
      • toBuilder

        public JavaFeaturesProto.JavaFeatures.Builder toBuilder()
        Specified by:
        toBuilder in interface com.google.protobuf.Message
        Specified by:
        toBuilder in interface com.google.protobuf.MessageLite
      • newBuilderForType

        protected JavaFeaturesProto.JavaFeatures.Builder newBuilderForType​(com.google.protobuf.AbstractMessage.BuilderParent parent)
        Overrides:
        newBuilderForType in class com.google.protobuf.AbstractMessage
      • getParserForType

        public com.google.protobuf.Parser<JavaFeaturesProto.JavaFeatures> getParserForType()
        Specified by:
        getParserForType in interface com.google.protobuf.Message
        Specified by:
        getParserForType in interface com.google.protobuf.MessageLite
        Overrides:
        getParserForType in class com.google.protobuf.GeneratedMessage
      • getDefaultInstanceForType

        public JavaFeaturesProto.JavaFeatures getDefaultInstanceForType()
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder