Class JavaFeaturesProto.JavaFeatures.Builder

    • Method Detail

      • getDescriptor

        public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
      • internalGetFieldAccessorTable

        protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
        Specified by:
        internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessage.Builder<JavaFeaturesProto.JavaFeatures.Builder>
      • getDescriptorForType

        public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
        Specified by:
        getDescriptorForType in interface com.google.protobuf.Message.Builder
        Specified by:
        getDescriptorForType in interface com.google.protobuf.MessageOrBuilder
        Overrides:
        getDescriptorForType in class com.google.protobuf.GeneratedMessage.Builder<JavaFeaturesProto.JavaFeatures.Builder>
      • getDefaultInstanceForType

        public JavaFeaturesProto.JavaFeatures getDefaultInstanceForType()
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder
      • build

        public JavaFeaturesProto.JavaFeatures build()
        Specified by:
        build in interface com.google.protobuf.Message.Builder
        Specified by:
        build in interface com.google.protobuf.MessageLite.Builder
      • buildPartial

        public JavaFeaturesProto.JavaFeatures buildPartial()
        Specified by:
        buildPartial in interface com.google.protobuf.Message.Builder
        Specified by:
        buildPartial in interface com.google.protobuf.MessageLite.Builder
      • isInitialized

        public final boolean isInitialized()
        Specified by:
        isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
        Overrides:
        isInitialized in class com.google.protobuf.GeneratedMessage.Builder<JavaFeaturesProto.JavaFeatures.Builder>
      • mergeFrom

        public JavaFeaturesProto.JavaFeatures.Builder mergeFrom​(com.google.protobuf.CodedInputStream input,
                                                                com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                         throws java.io.IOException
        Specified by:
        mergeFrom in interface com.google.protobuf.Message.Builder
        Specified by:
        mergeFrom in interface com.google.protobuf.MessageLite.Builder
        Overrides:
        mergeFrom in class com.google.protobuf.AbstractMessage.Builder<JavaFeaturesProto.JavaFeatures.Builder>
        Throws:
        java.io.IOException
      • hasLegacyClosedEnum

        public boolean hasLegacyClosedEnum()
         Whether or not to treat an enum field as closed.  This option is only
         applicable to enum fields, and will be removed in the future.  It is
         consistent with the legacy behavior of using proto3 enum types for proto2
         fields.
         
        optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Specified by:
        hasLegacyClosedEnum in interface JavaFeaturesProto.JavaFeaturesOrBuilder
        Returns:
        Whether the legacyClosedEnum field is set.
      • getLegacyClosedEnum

        public boolean getLegacyClosedEnum()
         Whether or not to treat an enum field as closed.  This option is only
         applicable to enum fields, and will be removed in the future.  It is
         consistent with the legacy behavior of using proto3 enum types for proto2
         fields.
         
        optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Specified by:
        getLegacyClosedEnum in interface JavaFeaturesProto.JavaFeaturesOrBuilder
        Returns:
        The legacyClosedEnum.
      • setLegacyClosedEnum

        public JavaFeaturesProto.JavaFeatures.Builder setLegacyClosedEnum​(boolean value)
         Whether or not to treat an enum field as closed.  This option is only
         applicable to enum fields, and will be removed in the future.  It is
         consistent with the legacy behavior of using proto3 enum types for proto2
         fields.
         
        optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Parameters:
        value - The legacyClosedEnum to set.
        Returns:
        This builder for chaining.
      • clearLegacyClosedEnum

        public JavaFeaturesProto.JavaFeatures.Builder clearLegacyClosedEnum()
         Whether or not to treat an enum field as closed.  This option is only
         applicable to enum fields, and will be removed in the future.  It is
         consistent with the legacy behavior of using proto3 enum types for proto2
         fields.
         
        optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Returns:
        This builder for chaining.
      • hasUtf8Validation

        public boolean hasUtf8Validation()
        optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Specified by:
        hasUtf8Validation in interface JavaFeaturesProto.JavaFeaturesOrBuilder
        Returns:
        Whether the utf8Validation field is set.
      • clearUtf8Validation

        public JavaFeaturesProto.JavaFeatures.Builder clearUtf8Validation()
        optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Returns:
        This builder for chaining.