Enum JavaFeaturesProto.JavaFeatures.Utf8Validation

    • Field Detail

      • UTF8_VALIDATION_UNKNOWN_VALUE

        public static final int UTF8_VALIDATION_UNKNOWN_VALUE
         Invalid default, which should never be used.
         
        UTF8_VALIDATION_UNKNOWN = 0;
        See Also:
        Constant Field Values
      • DEFAULT_VALUE

        public static final int DEFAULT_VALUE
         Respect the UTF8 validation behavior specified by the global
         utf8_validation feature.
         
        DEFAULT = 1;
        See Also:
        Constant Field Values
      • VERIFY_VALUE

        public static final int VERIFY_VALUE
         Verifies UTF8 validity overriding the global utf8_validation
         feature. This represents the legacy java_string_check_utf8 option.
         
        VERIFY = 2;
        See Also:
        Constant Field Values
    • Method Detail

      • values

        public static JavaFeaturesProto.JavaFeatures.Utf8Validation[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (JavaFeaturesProto.JavaFeatures.Utf8Validation c : JavaFeaturesProto.JavaFeatures.Utf8Validation.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static JavaFeaturesProto.JavaFeatures.Utf8Validation valueOf​(java.lang.String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        java.lang.IllegalArgumentException - if this enum type has no constant with the specified name
        java.lang.NullPointerException - if the argument is null
      • getNumber

        public final int getNumber()
        Specified by:
        getNumber in interface com.google.protobuf.Internal.EnumLite
        Specified by:
        getNumber in interface com.google.protobuf.ProtocolMessageEnum
      • valueOf

        @Deprecated
        public static JavaFeaturesProto.JavaFeatures.Utf8Validation valueOf​(int value)
        Deprecated.
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        value - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        java.lang.IllegalArgumentException - if this enum type has no constant with the specified name
        java.lang.NullPointerException - if the argument is null
      • forNumber

        public static JavaFeaturesProto.JavaFeatures.Utf8Validation forNumber​(int value)
        Parameters:
        value - The numeric wire value of the corresponding enum entry.
        Returns:
        The enum associated with the given numeric wire value.
      • getValueDescriptor

        public final com.google.protobuf.Descriptors.EnumValueDescriptor getValueDescriptor()
        Specified by:
        getValueDescriptor in interface com.google.protobuf.ProtocolMessageEnum
      • getDescriptorForType

        public final com.google.protobuf.Descriptors.EnumDescriptor getDescriptorForType()
        Specified by:
        getDescriptorForType in interface com.google.protobuf.ProtocolMessageEnum
      • getDescriptor

        public static final com.google.protobuf.Descriptors.EnumDescriptor getDescriptor()
      • valueOf

        public static JavaFeaturesProto.JavaFeatures.Utf8Validation valueOf​(com.google.protobuf.Descriptors.EnumValueDescriptor desc)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        desc - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        java.lang.IllegalArgumentException - if this enum type has no constant with the specified name
        java.lang.NullPointerException - if the argument is null