Interface JavaFeaturesProto.JavaFeaturesOrBuilder

    • Method Summary

      All Methods Instance Methods Abstract Methods 
      Modifier and Type Method Description
      boolean getLegacyClosedEnum()
      Whether or not to treat an enum field as closed.
      JavaFeaturesProto.JavaFeatures.Utf8Validation getUtf8Validation()
      optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ...
      boolean hasLegacyClosedEnum()
      Whether or not to treat an enum field as closed.
      boolean hasUtf8Validation()
      optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ...
      • Methods inherited from interface com.google.protobuf.MessageLiteOrBuilder

        isInitialized
      • Methods inherited from interface com.google.protobuf.MessageOrBuilder

        findInitializationErrors, getAllFields, getDefaultInstanceForType, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
    • Method Detail

      • hasLegacyClosedEnum

        boolean hasLegacyClosedEnum()
         Whether or not to treat an enum field as closed.  This option is only
         applicable to enum fields, and will be removed in the future.  It is
         consistent with the legacy behavior of using proto3 enum types for proto2
         fields.
         
        optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Returns:
        Whether the legacyClosedEnum field is set.
      • getLegacyClosedEnum

        boolean getLegacyClosedEnum()
         Whether or not to treat an enum field as closed.  This option is only
         applicable to enum fields, and will be removed in the future.  It is
         consistent with the legacy behavior of using proto3 enum types for proto2
         fields.
         
        optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Returns:
        The legacyClosedEnum.
      • hasUtf8Validation

        boolean hasUtf8Validation()
        optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Returns:
        Whether the utf8Validation field is set.
      • getUtf8Validation

        JavaFeaturesProto.JavaFeatures.Utf8Validation getUtf8Validation()
        optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }
        Returns:
        The utf8Validation.