Package dev.sigstore
Class AlgorithmRegistry
java.lang.Object
dev.sigstore.AlgorithmRegistry
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic enumstatic enum -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiongetSigningAlgorithm(PublicKey publicKey) Determine the signing algorithm based on the public key.
-
Constructor Details
-
AlgorithmRegistry
public AlgorithmRegistry()
-
-
Method Details
-
getSigningAlgorithm
public static AlgorithmRegistry.SigningAlgorithm getSigningAlgorithm(PublicKey publicKey) throws UnsupportedAlgorithmException Determine the signing algorithm based on the public key.- Parameters:
publicKey- the public key- Returns:
- the signing algorithm
- Throws:
UnsupportedAlgorithmException- if the key algorithm or curve is not supportedIllegalStateException- if the public key cannot be converted into a known type
-