Package dev.sigstore

Interface KeylessSignature


  • @Immutable
    public interface KeylessSignature
    • Method Summary

      All Methods Static Methods Instance Methods Abstract Methods 
      Modifier and Type Method Description
      static dev.sigstore.ImmutableKeylessSignature.Builder builder()  
      java.security.cert.CertPath getCertPath()
      The partial certificate chain provided by fulcio for the public key and identity used to sign the artifact, this should NOT contain the trusted root or any trusted intermediates.
      byte[] getDigest()
      The sha256 hash digest of the artifact, this may be empty and should be treated as not present in that case.
      java.util.Optional<RekorEntry> getEntry()
      The entry in the rekor transparency log
      byte[] getSignature()
      The signature over the artifact
    • Method Detail

      • getDigest

        byte[] getDigest()
        The sha256 hash digest of the artifact, this may be empty and should be treated as not present in that case.
      • getCertPath

        java.security.cert.CertPath getCertPath()
        The partial certificate chain provided by fulcio for the public key and identity used to sign the artifact, this should NOT contain the trusted root or any trusted intermediates. But users of this object should understand that older signatures may include the full chain.
      • getSignature

        byte[] getSignature()
        The signature over the artifact
      • getEntry

        java.util.Optional<RekorEntry> getEntry()
        The entry in the rekor transparency log
      • builder

        static dev.sigstore.ImmutableKeylessSignature.Builder builder()