Package dev.sigstore

Class KeylessSigner

java.lang.Object
dev.sigstore.KeylessSigner
All Implemented Interfaces:
AutoCloseable

public class KeylessSigner extends Object implements AutoCloseable
A full sigstore keyless signing flow.

Note: the implementation is thread-safe assuming the clients (Fulcio, OIDC, Rekor) are thread-safe

  • Field Details

    • DEFAULT_MIN_SIGNING_CERTIFICATE_LIFETIME

      public static final Duration DEFAULT_MIN_SIGNING_CERTIFICATE_LIFETIME
      The instance of the KeylessSigner will try to reuse a previously acquired certificate if the expiration time on the certificate is more than minSigningCertificateLifetime time away. Otherwise, it will make a new request (OIDC, Fulcio) to obtain a new updated certificate to use for signing. This is a default value for the remaining lifetime of the signing certificate that is considered good enough.
    • DEFAULT_INTOTO_PAYLOAD_TYPE

      public static final String DEFAULT_INTOTO_PAYLOAD_TYPE
      See Also:
  • Method Details