Package dev.sigstore
Class KeylessVerifier
java.lang.Object
dev.sigstore.KeylessVerifier
Verify hashedrekords from rekor signed using the keyless signing flow with fulcio certificates.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic KeylessVerifier.Builderbuilder()voidverify(byte[] artifactDigest, Bundle bundle, VerificationOptions options) Verify that the inputs can attest to the validity of a signature using sigstore's keyless infrastructure.voidverify(Path artifact, Bundle bundle, VerificationOptions options) Convenience wrapper aroundverify(byte[], Bundle, VerificationOptions).
-
Method Details
-
builder
-
verify
public void verify(Path artifact, Bundle bundle, VerificationOptions options) throws KeylessVerificationException Convenience wrapper aroundverify(byte[], Bundle, VerificationOptions).- Throws:
KeylessVerificationException
-
verify
public void verify(byte[] artifactDigest, Bundle bundle, VerificationOptions options) throws KeylessVerificationException Verify that the inputs can attest to the validity of a signature using sigstore's keyless infrastructure. If no exception is thrown, it should be assumed verification has passed.- Parameters:
artifactDigest- the sha256 digest of the artifact that is being verifiedbundle- the sigstore signature bundle to verifyoptions- the keyless verification data and options- Throws:
KeylessVerificationException- if the signing information could not be verified
-