Package dev.sigstore
Interface SigningConfigProvider
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
-
Method Summary
Modifier and TypeMethodDescriptionstatic SigningConfigProviderfrom(SigstoreTufClient.Builder tufClientBuilder) static SigningConfigProviderget()
-
Method Details
-
get
- Throws:
SigstoreConfigurationException
-
from
-
from
-