Package dev.sigstore
Interface VerificationOptions
@Immutable(singleton=true)
public interface VerificationOptions
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceAn interface for allowing matching of certificates.static classExceptions thrown by implementations ofVerificationOptions.CertificateMatcher.test(X509Certificate) -
Method Summary
Modifier and TypeMethodDescriptionstatic dev.sigstore.ImmutableVerificationOptions.Builderbuilder()static VerificationOptionsempty()An allow list of certificate identities to match with.
-
Method Details
-
getCertificateMatchers
List<VerificationOptions.CertificateMatcher> getCertificateMatchers()An allow list of certificate identities to match with. -
builder
static dev.sigstore.ImmutableVerificationOptions.Builder builder() -
empty
-