Package dev.sigstore.bundle
Class BundleFactory
- java.lang.Object
-
- dev.sigstore.bundle.BundleFactory
-
public class BundleFactory extends java.lang.ObjectCompat class, needed for build to continue to work while we make API changes.
-
-
Constructor Summary
Constructors Constructor Description BundleFactory()
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static java.lang.StringcreateBundle(KeylessSignature keylessSignature)
-
-
-
Method Detail
-
createBundle
public static java.lang.String createBundle(KeylessSignature keylessSignature)
-
-