Class HttpClients

java.lang.Object
dev.sigstore.http.HttpClients

public class HttpClients extends Object
HttpClients generates Google Http Client objects from configuration.
  • Constructor Details

    • HttpClients

      public HttpClients()
  • Method Details

    • newHttpTransport

      public static com.google.api.client.http.HttpTransport newHttpTransport(HttpParams httpParams)
      Build a transport, you probably want to use newRequestFactory(HttpParams) to instantiate GET and POST requests or use if you need to also configure the response parser.
    • newRequestFactory

      public static com.google.api.client.http.HttpRequestFactory newRequestFactory(HttpParams httpParams)
      Create a new get requests with the httpParams applied and retries.
    • newRequestFactory

      public static com.google.api.client.http.HttpRequestFactory newRequestFactory(HttpParams httpParams, @Nullable com.google.api.client.util.ObjectParser responseParser)
      Create a new get requests with the httpParams applied, retries and a response parser.