Class UnsuccessfulResponseHandler

java.lang.Object
dev.sigstore.http.UnsuccessfulResponseHandler
All Implemented Interfaces:
com.google.api.client.http.HttpUnsuccessfulResponseHandler

public class UnsuccessfulResponseHandler extends Object implements com.google.api.client.http.HttpUnsuccessfulResponseHandler
Handler for 429 and standard server errors 5XX. Objects of this class are single use. A new instance should be created for each request (but this is handled in HttpClients.newRequestFactory(HttpParams)).

This implementation is a bit weird, but hopefully we can just move to grpc for rekor when ready.

  • Method Details

    • newUnsuccessfulResponseHandler

      public static UnsuccessfulResponseHandler newUnsuccessfulResponseHandler()
    • handleResponse

      public boolean handleResponse(com.google.api.client.http.HttpRequest request, com.google.api.client.http.HttpResponse response, boolean supportsRetry) throws IOException
      Specified by:
      handleResponse in interface com.google.api.client.http.HttpUnsuccessfulResponseHandler
      Throws:
      IOException