Interface TimestampRequest


@Immutable public interface TimestampRequest
  • Method Details

    • getHashAlgorithm

      The hash algorithm used to hash the artifact.
    • getHash

      byte[] getHash()
      The hash of the artifact to be timestamped. For sigstore-java, this typically refers to the hash of the signature (not the original artifact's hash) in a signing event.
    • getNonce

      @Default default BigInteger getNonce()
      A nonce to prevent replay attacks. Defaults to a 64-bit random number.
    • requestCertificates

      @Default default Boolean requestCertificates()
      Whether or not to include certificates in the response. Defaults to false.