Package dev.sigstore.timestamp.client
Class TimestampVerifier
java.lang.Object
dev.sigstore.timestamp.client.TimestampVerifier
-
Method Summary
Modifier and TypeMethodDescriptionstatic TimestampVerifiernewTimestampVerifier(SigstoreTrustedRoot trustedRoot) static TimestampVerifiervoidverify(TimestampResponse tsResp, byte[] artifact) Verifies a timestamp response against the configured trusted Timestamp Authorities (TSAs).
-
Method Details
-
newTimestampVerifier
public static TimestampVerifier newTimestampVerifier(SigstoreTrustedRoot trustedRoot) throws InvalidAlgorithmParameterException, CertificateException, InvalidKeySpecException, NoSuchAlgorithmException -
newTimestampVerifier
public static TimestampVerifier newTimestampVerifier(List<CertificateAuthority> tsas) throws InvalidKeySpecException, NoSuchAlgorithmException, InvalidAlgorithmParameterException, CertificateException -
verify
Verifies a timestamp response against the configured trusted Timestamp Authorities (TSAs).- Parameters:
tsResp- The timestamp response object containing the raw bytes of the RFC 3161 TimeStampResponse.artifact- The artifact that was timestamped.- Throws:
TimestampVerificationException- if any verification step fails (e.g., no token, certificate path validation failure, signature validation failure).
-