Package dev.sigstore.trustroot
Interface TransparencyLog
@Immutable
public interface TransparencyLog
-
Method Summary
Modifier and TypeMethodDescriptionstatic Optional<TransparencyLog> find(List<TransparencyLog> all, byte[] logId) Find a log by logId.static Optional<TransparencyLog> find(List<TransparencyLog> all, byte[] logId, Instant time) Find a log by validity time and logId.static TransparencyLogfrom(TransparencyLogInstance proto) getLogId()
-
Method Details
-
getBaseUrl
URI getBaseUrl() -
getHashAlgorithm
String getHashAlgorithm() -
getLogId
LogId getLogId() -
getPublicKey
PublicKey getPublicKey() -
from
-
find
Find a log by logId.- Parameters:
logId- the logId of the log- Returns:
- the first log with matching
logId
-
find
Find a log by validity time and logId. This will find the first log with matching log id that was valid at the time.- Parameters:
logId- the logId of the logtime- the time the log was expected to be valid- Returns:
- the first log that was valid at
timewith logIdlogId
-