Interface RootProvider

Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface RootProvider
An interface for providing the tuf root to a client.