Package com.google.api
Class AuthRequirement.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<AuthRequirement.Builder>
-
- com.google.api.AuthRequirement.Builder
-
- All Implemented Interfaces:
AuthRequirementOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- AuthRequirement
public static final class AuthRequirement.Builder extends com.google.protobuf.GeneratedMessage.Builder<AuthRequirement.Builder> implements AuthRequirementOrBuilder
User-defined authentication requirements, including support for [JSON Web Token (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
Protobuf typegoogle.api.AuthRequirement
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description AuthRequirementbuild()AuthRequirementbuildPartial()AuthRequirement.Builderclear()AuthRequirement.BuilderclearAudiences()NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components.AuthRequirement.BuilderclearProviderId()[id][google.api.AuthProvider.id] from authentication provider.java.lang.StringgetAudiences()NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components.com.google.protobuf.ByteStringgetAudiencesBytes()NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components.AuthRequirementgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()java.lang.StringgetProviderId()[id][google.api.AuthProvider.id] from authentication provider.com.google.protobuf.ByteStringgetProviderIdBytes()[id][google.api.AuthProvider.id] from authentication provider.protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()AuthRequirement.BuildermergeFrom(AuthRequirement other)AuthRequirement.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)AuthRequirement.BuildermergeFrom(com.google.protobuf.Message other)AuthRequirement.BuildersetAudiences(java.lang.String value)NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components.AuthRequirement.BuildersetAudiencesBytes(com.google.protobuf.ByteString value)NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components.AuthRequirement.BuildersetProviderId(java.lang.String value)[id][google.api.AuthProvider.id] from authentication provider.AuthRequirement.BuildersetProviderIdBytes(com.google.protobuf.ByteString value)[id][google.api.AuthProvider.id] from authentication provider.-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<AuthRequirement.Builder>
-
clear
public AuthRequirement.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<AuthRequirement.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<AuthRequirement.Builder>
-
getDefaultInstanceForType
public AuthRequirement getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public AuthRequirement build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public AuthRequirement buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public AuthRequirement.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<AuthRequirement.Builder>
-
mergeFrom
public AuthRequirement.Builder mergeFrom(AuthRequirement other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<AuthRequirement.Builder>
-
mergeFrom
public AuthRequirement.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<AuthRequirement.Builder>- Throws:
java.io.IOException
-
getProviderId
public java.lang.String getProviderId()
[id][google.api.AuthProvider.id] from authentication provider. Example: provider_id: bookstore_auth
string provider_id = 1;- Specified by:
getProviderIdin interfaceAuthRequirementOrBuilder- Returns:
- The providerId.
-
getProviderIdBytes
public com.google.protobuf.ByteString getProviderIdBytes()
[id][google.api.AuthProvider.id] from authentication provider. Example: provider_id: bookstore_auth
string provider_id = 1;- Specified by:
getProviderIdBytesin interfaceAuthRequirementOrBuilder- Returns:
- The bytes for providerId.
-
setProviderId
public AuthRequirement.Builder setProviderId(java.lang.String value)
[id][google.api.AuthProvider.id] from authentication provider. Example: provider_id: bookstore_auth
string provider_id = 1;- Parameters:
value- The providerId to set.- Returns:
- This builder for chaining.
-
clearProviderId
public AuthRequirement.Builder clearProviderId()
[id][google.api.AuthProvider.id] from authentication provider. Example: provider_id: bookstore_auth
string provider_id = 1;- Returns:
- This builder for chaining.
-
setProviderIdBytes
public AuthRequirement.Builder setProviderIdBytes(com.google.protobuf.ByteString value)
[id][google.api.AuthProvider.id] from authentication provider. Example: provider_id: bookstore_auth
string provider_id = 1;- Parameters:
value- The bytes for providerId to set.- Returns:
- This builder for chaining.
-
getAudiences
public java.lang.String getAudiences()
NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components. The list of JWT [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3). that are allowed to access. A JWT containing any of these audiences will be accepted. When this setting is absent, only JWTs with audience "https://[Service_name][google.api.Service.name]/[API_name][google.protobuf.Api.name]" will be accepted. For example, if no audiences are in the setting, LibraryService API will only accept JWTs with the following audience "https://library-example.googleapis.com/google.example.library.v1.LibraryService". Example: audiences: bookstore_android.apps.googleusercontent.com, bookstore_web.apps.googleusercontent.com
string audiences = 2;- Specified by:
getAudiencesin interfaceAuthRequirementOrBuilder- Returns:
- The audiences.
-
getAudiencesBytes
public com.google.protobuf.ByteString getAudiencesBytes()
NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components. The list of JWT [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3). that are allowed to access. A JWT containing any of these audiences will be accepted. When this setting is absent, only JWTs with audience "https://[Service_name][google.api.Service.name]/[API_name][google.protobuf.Api.name]" will be accepted. For example, if no audiences are in the setting, LibraryService API will only accept JWTs with the following audience "https://library-example.googleapis.com/google.example.library.v1.LibraryService". Example: audiences: bookstore_android.apps.googleusercontent.com, bookstore_web.apps.googleusercontent.com
string audiences = 2;- Specified by:
getAudiencesBytesin interfaceAuthRequirementOrBuilder- Returns:
- The bytes for audiences.
-
setAudiences
public AuthRequirement.Builder setAudiences(java.lang.String value)
NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components. The list of JWT [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3). that are allowed to access. A JWT containing any of these audiences will be accepted. When this setting is absent, only JWTs with audience "https://[Service_name][google.api.Service.name]/[API_name][google.protobuf.Api.name]" will be accepted. For example, if no audiences are in the setting, LibraryService API will only accept JWTs with the following audience "https://library-example.googleapis.com/google.example.library.v1.LibraryService". Example: audiences: bookstore_android.apps.googleusercontent.com, bookstore_web.apps.googleusercontent.com
string audiences = 2;- Parameters:
value- The audiences to set.- Returns:
- This builder for chaining.
-
clearAudiences
public AuthRequirement.Builder clearAudiences()
NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components. The list of JWT [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3). that are allowed to access. A JWT containing any of these audiences will be accepted. When this setting is absent, only JWTs with audience "https://[Service_name][google.api.Service.name]/[API_name][google.protobuf.Api.name]" will be accepted. For example, if no audiences are in the setting, LibraryService API will only accept JWTs with the following audience "https://library-example.googleapis.com/google.example.library.v1.LibraryService". Example: audiences: bookstore_android.apps.googleusercontent.com, bookstore_web.apps.googleusercontent.com
string audiences = 2;- Returns:
- This builder for chaining.
-
setAudiencesBytes
public AuthRequirement.Builder setAudiencesBytes(com.google.protobuf.ByteString value)
NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components. The list of JWT [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3). that are allowed to access. A JWT containing any of these audiences will be accepted. When this setting is absent, only JWTs with audience "https://[Service_name][google.api.Service.name]/[API_name][google.protobuf.Api.name]" will be accepted. For example, if no audiences are in the setting, LibraryService API will only accept JWTs with the following audience "https://library-example.googleapis.com/google.example.library.v1.LibraryService". Example: audiences: bookstore_android.apps.googleusercontent.com, bookstore_web.apps.googleusercontent.com
string audiences = 2;- Parameters:
value- The bytes for audiences to set.- Returns:
- This builder for chaining.
-
-