Package com.google.api
Class Distribution.BucketOptions.Explicit.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Explicit.Builder>
-
- com.google.api.Distribution.BucketOptions.Explicit.Builder
-
- All Implemented Interfaces:
Distribution.BucketOptions.ExplicitOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.lang.Cloneable
- Enclosing class:
- Distribution.BucketOptions.Explicit
public static final class Distribution.BucketOptions.Explicit.Builder extends com.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Explicit.Builder> implements Distribution.BucketOptions.ExplicitOrBuilder
Specifies a set of buckets with arbitrary widths. There are `size(bounds) + 1` (= N) buckets. Bucket `i` has the following boundaries: Upper bound (0 <= i < N-1): bounds[i] Lower bound (1 <= i < N); bounds[i - 1] The `bounds` field must contain at least one element. If `bounds` has only one element, then there are no finite buckets, and that single element is the common boundary of the overflow and underflow buckets.
Protobuf typegoogle.api.Distribution.BucketOptions.Explicit
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description Distribution.BucketOptions.Explicit.BuilderaddAllBounds(java.lang.Iterable<? extends java.lang.Double> values)The values must be monotonically increasing.Distribution.BucketOptions.Explicit.BuilderaddBounds(double value)The values must be monotonically increasing.Distribution.BucketOptions.Explicitbuild()Distribution.BucketOptions.ExplicitbuildPartial()Distribution.BucketOptions.Explicit.Builderclear()Distribution.BucketOptions.Explicit.BuilderclearBounds()The values must be monotonically increasing.doublegetBounds(int index)The values must be monotonically increasing.intgetBoundsCount()The values must be monotonically increasing.java.util.List<java.lang.Double>getBoundsList()The values must be monotonically increasing.Distribution.BucketOptions.ExplicitgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()Distribution.BucketOptions.Explicit.BuildermergeFrom(Distribution.BucketOptions.Explicit other)Distribution.BucketOptions.Explicit.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)Distribution.BucketOptions.Explicit.BuildermergeFrom(com.google.protobuf.Message other)Distribution.BucketOptions.Explicit.BuildersetBounds(int index, double value)The values must be monotonically increasing.-
Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Explicit.Builder>
-
clear
public Distribution.BucketOptions.Explicit.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Explicit.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Explicit.Builder>
-
getDefaultInstanceForType
public Distribution.BucketOptions.Explicit getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public Distribution.BucketOptions.Explicit build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public Distribution.BucketOptions.Explicit buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public Distribution.BucketOptions.Explicit.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Distribution.BucketOptions.Explicit.Builder>
-
mergeFrom
public Distribution.BucketOptions.Explicit.Builder mergeFrom(Distribution.BucketOptions.Explicit other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<Distribution.BucketOptions.Explicit.Builder>
-
mergeFrom
public Distribution.BucketOptions.Explicit.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Distribution.BucketOptions.Explicit.Builder>- Throws:
java.io.IOException
-
getBoundsList
public java.util.List<java.lang.Double> getBoundsList()
The values must be monotonically increasing.
repeated double bounds = 1;- Specified by:
getBoundsListin interfaceDistribution.BucketOptions.ExplicitOrBuilder- Returns:
- A list containing the bounds.
-
getBoundsCount
public int getBoundsCount()
The values must be monotonically increasing.
repeated double bounds = 1;- Specified by:
getBoundsCountin interfaceDistribution.BucketOptions.ExplicitOrBuilder- Returns:
- The count of bounds.
-
getBounds
public double getBounds(int index)
The values must be monotonically increasing.
repeated double bounds = 1;- Specified by:
getBoundsin interfaceDistribution.BucketOptions.ExplicitOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The bounds at the given index.
-
setBounds
public Distribution.BucketOptions.Explicit.Builder setBounds(int index, double value)
The values must be monotonically increasing.
repeated double bounds = 1;- Parameters:
index- The index to set the value at.value- The bounds to set.- Returns:
- This builder for chaining.
-
addBounds
public Distribution.BucketOptions.Explicit.Builder addBounds(double value)
The values must be monotonically increasing.
repeated double bounds = 1;- Parameters:
value- The bounds to add.- Returns:
- This builder for chaining.
-
addAllBounds
public Distribution.BucketOptions.Explicit.Builder addAllBounds(java.lang.Iterable<? extends java.lang.Double> values)
The values must be monotonically increasing.
repeated double bounds = 1;- Parameters:
values- The bounds to add.- Returns:
- This builder for chaining.
-
clearBounds
public Distribution.BucketOptions.Explicit.Builder clearBounds()
The values must be monotonically increasing.
repeated double bounds = 1;- Returns:
- This builder for chaining.
-
-