Package com.google.protobuf
Class JavaFeaturesProto.JavaFeatures
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessage
-
- com.google.protobuf.JavaFeaturesProto.JavaFeatures
-
- All Implemented Interfaces:
JavaFeaturesProto.JavaFeaturesOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,java.io.Serializable
- Enclosing class:
- JavaFeaturesProto
public static final class JavaFeaturesProto.JavaFeatures extends com.google.protobuf.GeneratedMessage implements JavaFeaturesProto.JavaFeaturesOrBuilder
Protobuf typepb.JavaFeatures- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classJavaFeaturesProto.JavaFeatures.BuilderProtobuf typepb.JavaFeaturesstatic classJavaFeaturesProto.JavaFeatures.Utf8ValidationThe UTF8 validation strategy to use.-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessage
com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessage.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessage.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessage.FieldAccessorTable, com.google.protobuf.GeneratedMessage.GeneratedExtension<ContainingT extends com.google.protobuf.Message,T extends java.lang.Object>, com.google.protobuf.GeneratedMessage.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intLEGACY_CLOSED_ENUM_FIELD_NUMBERstatic intUTF8_VALIDATION_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(java.lang.Object obj)static JavaFeaturesProto.JavaFeaturesgetDefaultInstance()JavaFeaturesProto.JavaFeaturesgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()booleangetLegacyClosedEnum()Whether or not to treat an enum field as closed.com.google.protobuf.Parser<JavaFeaturesProto.JavaFeatures>getParserForType()intgetSerializedSize()JavaFeaturesProto.JavaFeatures.Utf8ValidationgetUtf8Validation()optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ...inthashCode()booleanhasLegacyClosedEnum()Whether or not to treat an enum field as closed.booleanhasUtf8Validation()optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ...protected com.google.protobuf.GeneratedMessage.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static JavaFeaturesProto.JavaFeatures.BuildernewBuilder()static JavaFeaturesProto.JavaFeatures.BuildernewBuilder(JavaFeaturesProto.JavaFeatures prototype)JavaFeaturesProto.JavaFeatures.BuildernewBuilderForType()protected JavaFeaturesProto.JavaFeatures.BuildernewBuilderForType(com.google.protobuf.AbstractMessage.BuilderParent parent)static JavaFeaturesProto.JavaFeaturesparseDelimitedFrom(java.io.InputStream input)static JavaFeaturesProto.JavaFeaturesparseDelimitedFrom(java.io.InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static JavaFeaturesProto.JavaFeaturesparseFrom(byte[] data)static JavaFeaturesProto.JavaFeaturesparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static JavaFeaturesProto.JavaFeaturesparseFrom(com.google.protobuf.ByteString data)static JavaFeaturesProto.JavaFeaturesparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static JavaFeaturesProto.JavaFeaturesparseFrom(com.google.protobuf.CodedInputStream input)static JavaFeaturesProto.JavaFeaturesparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static JavaFeaturesProto.JavaFeaturesparseFrom(java.io.InputStream input)static JavaFeaturesProto.JavaFeaturesparseFrom(java.io.InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static JavaFeaturesProto.JavaFeaturesparseFrom(java.nio.ByteBuffer data)static JavaFeaturesProto.JavaFeaturesparseFrom(java.nio.ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<JavaFeaturesProto.JavaFeatures>parser()JavaFeaturesProto.JavaFeatures.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessage
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, newFileScopedGeneratedExtension, newInstance, newMessageScopedGeneratedExtension, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashFields, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
LEGACY_CLOSED_ENUM_FIELD_NUMBER
public static final int LEGACY_CLOSED_ENUM_FIELD_NUMBER
- See Also:
- Constant Field Values
-
UTF8_VALIDATION_FIELD_NUMBER
public static final int UTF8_VALIDATION_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage
-
hasLegacyClosedEnum
public boolean hasLegacyClosedEnum()
Whether or not to treat an enum field as closed. This option is only applicable to enum fields, and will be removed in the future. It is consistent with the legacy behavior of using proto3 enum types for proto2 fields.
optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }- Specified by:
hasLegacyClosedEnumin interfaceJavaFeaturesProto.JavaFeaturesOrBuilder- Returns:
- Whether the legacyClosedEnum field is set.
-
getLegacyClosedEnum
public boolean getLegacyClosedEnum()
Whether or not to treat an enum field as closed. This option is only applicable to enum fields, and will be removed in the future. It is consistent with the legacy behavior of using proto3 enum types for proto2 fields.
optional bool legacy_closed_enum = 1 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }- Specified by:
getLegacyClosedEnumin interfaceJavaFeaturesProto.JavaFeaturesOrBuilder- Returns:
- The legacyClosedEnum.
-
hasUtf8Validation
public boolean hasUtf8Validation()
optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }- Specified by:
hasUtf8Validationin interfaceJavaFeaturesProto.JavaFeaturesOrBuilder- Returns:
- Whether the utf8Validation field is set.
-
getUtf8Validation
public JavaFeaturesProto.JavaFeatures.Utf8Validation getUtf8Validation()
optional .pb.JavaFeatures.Utf8Validation utf8_validation = 2 [retention = RETENTION_RUNTIME, targets = TARGET_TYPE_FIELD, targets = TARGET_TYPE_FILE, edition_defaults = { ... }- Specified by:
getUtf8Validationin interfaceJavaFeaturesProto.JavaFeaturesOrBuilder- Returns:
- The utf8Validation.
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws java.io.IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessage- Throws:
java.io.IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessage
-
equals
public boolean equals(java.lang.Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(java.nio.ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(java.nio.ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(java.io.InputStream input) throws java.io.IOException
- Throws:
java.io.IOException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(java.io.InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Throws:
java.io.IOException
-
parseDelimitedFrom
public static JavaFeaturesProto.JavaFeatures parseDelimitedFrom(java.io.InputStream input) throws java.io.IOException
- Throws:
java.io.IOException
-
parseDelimitedFrom
public static JavaFeaturesProto.JavaFeatures parseDelimitedFrom(java.io.InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Throws:
java.io.IOException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(com.google.protobuf.CodedInputStream input) throws java.io.IOException
- Throws:
java.io.IOException
-
parseFrom
public static JavaFeaturesProto.JavaFeatures parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws java.io.IOException
- Throws:
java.io.IOException
-
newBuilderForType
public JavaFeaturesProto.JavaFeatures.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static JavaFeaturesProto.JavaFeatures.Builder newBuilder()
-
newBuilder
public static JavaFeaturesProto.JavaFeatures.Builder newBuilder(JavaFeaturesProto.JavaFeatures prototype)
-
toBuilder
public JavaFeaturesProto.JavaFeatures.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected JavaFeaturesProto.JavaFeatures.Builder newBuilderForType(com.google.protobuf.AbstractMessage.BuilderParent parent)
- Overrides:
newBuilderForTypein classcom.google.protobuf.AbstractMessage
-
getDefaultInstance
public static JavaFeaturesProto.JavaFeatures getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<JavaFeaturesProto.JavaFeatures> parser()
-
getParserForType
public com.google.protobuf.Parser<JavaFeaturesProto.JavaFeatures> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessage
-
getDefaultInstanceForType
public JavaFeaturesProto.JavaFeatures getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-