Package dev.sigstore.bundle
Class Bundle
java.lang.Object
dev.sigstore.bundle.Bundle
A representation of sigstore signing materials. See protobuf-specs
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interfacestatic interfacestatic interfacestatic interface -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected voidprotected voidstatic BundleRead a json formatted bundle.static BundleRead a json formatted bundle from a file.abstract CertPathThe partial certificate chain provided by fulcio for the public key and identity used to sign the artifact, this should NOT contain the trusted root or any trusted intermediates.abstract Optional<Bundle.DsseEnvelope> A DSSE envelope signature type that may contain an arbitrary payloadabstract List<RekorEntry> The entry in the rekor transparency log (represented as a list for future compatibility, but currently only allow for at most one entry.The bundle versionabstract Optional<Bundle.MessageSignature> A signature represented as a signature and digestabstract List<Bundle.Timestamp> A list of timestamps to verify the time of signing.toJson()
-
Constructor Details
-
Bundle
public Bundle()
-
-
Method Details
-
getMediaType
The bundle version -
getMessageSignature
A signature represented as a signature and digest -
getDsseEnvelope
A DSSE envelope signature type that may contain an arbitrary payload -
checkOnlyOneSignature
@Check protected void checkOnlyOneSignature() -
checkAtLeastOneTimestamp
@Check protected void checkAtLeastOneTimestamp() -
getCertPath
The partial certificate chain provided by fulcio for the public key and identity used to sign the artifact, this should NOT contain the trusted root or any trusted intermediates. But users of this object should understand that older signatures may include the full chain. -
getEntries
The entry in the rekor transparency log (represented as a list for future compatibility, but currently only allow for at most one entry. -
getTimestamps
A list of timestamps to verify the time of signing. Currently, allows rfc3161 timestamps. -
from
Read a json formatted bundle.- Throws:
BundleParseException
-
from
Read a json formatted bundle from a file.- Throws:
BundleParseExceptionIOException
-
toJson
-