Package dev.sigstore.http
Class HttpClients
java.lang.Object
dev.sigstore.http.HttpClients
HttpClients generates Google Http Client objects from configuration.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic com.google.api.client.http.HttpTransportnewHttpTransport(HttpParams httpParams) Build a transport, you probably want to usenewRequestFactory(HttpParams)to instantiate GET and POST requests or useif you need to also configure the response parser.static com.google.api.client.http.HttpRequestFactorynewRequestFactory(HttpParams httpParams) Create a new get requests with the httpParams applied and retries.static com.google.api.client.http.HttpRequestFactorynewRequestFactory(HttpParams httpParams, com.google.api.client.util.ObjectParser responseParser) Create a new get requests with the httpParams applied, retries and a response parser.
-
Constructor Details
-
HttpClients
public HttpClients()
-
-
Method Details
-
newHttpTransport
Build a transport, you probably want to usenewRequestFactory(HttpParams)to instantiate GET and POST requests or useif you need to also configure the response parser. -
newRequestFactory
public static com.google.api.client.http.HttpRequestFactory newRequestFactory(HttpParams httpParams) Create a new get requests with the httpParams applied and retries. -
newRequestFactory
public static com.google.api.client.http.HttpRequestFactory newRequestFactory(HttpParams httpParams, @Nullable com.google.api.client.util.ObjectParser responseParser) Create a new get requests with the httpParams applied, retries and a response parser.
-