Package dev.sigstore.tuf
Interface RootProvider
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
An interface for providing the tuf root to a client.
-
Method Summary
Modifier and TypeMethodDescriptionstatic RootProviderstatic RootProviderfromResource(String resourceName) get()
-
Method Details
-
get
- Throws:
IOException
-
fromResource
-
fromFile
-